package prova.med.NFCutils;

import java.io.UnsupportedEncodingException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Arrays;
import java.util.Locale;

import android.content.Intent;
import android.nfc.NdefMessage;
import android.nfc.NdefRecord;
import android.nfc.NfcAdapter;
import android.os.Parcelable;

public class NFCreading {

	static public NdefMessage[] readNdefMessageFromTag(Intent intent)
	{
		NdefMessage[] message = null;
		Parcelable[] rawMessages = intent.getParcelableArrayExtra(NfcAdapter.EXTRA_NDEF_MESSAGES);
		if (rawMessages != null) {
			message = new NdefMessage[rawMessages.length];
			for (int i = 0; i < rawMessages.length; i++) {
				message[i] = (NdefMessage) rawMessages[i];
			}
		} else {
			byte[] empty = new byte[] {};
			NdefRecord record = new NdefRecord ( NdefRecord.TNF_UNKNOWN, empty, empty, empty );
			NdefMessage msg = new NdefMessage( new NdefRecord[] { record } );
			message = new NdefMessage[] { msg };
		}

		return message;
	}

	static public String[] readRecordsFromMessage(NdefMessage message)
	{
		// 3 Record: codice a barre, data e ora
		String[] result = new String[3];
		for(int j=0; j<3 ; j++)
		{

			NdefRecord record = message.getRecords()[j];
			if(record.getTnf() != NdefRecord.TNF_WELL_KNOWN || !Arrays.equals(record.getType(), NdefRecord.RTD_TEXT))
				return null;
			byte[] payload = record.getPayload();
			//Text Encoding
			String textEncoding = ((payload[0] & 128) == 0) ? "UTF-8" : "UTF-16";
			//Language Code
			int languageCodeLength = payload[0] & 0063;

			try {
				result[j] = new String(payload, languageCodeLength + 1, payload.length - languageCodeLength - 1, textEncoding);
			} catch (UnsupportedEncodingException e) {

				return null;
			}
		}

		if(CorrectParsing(result))
			return result;
		else return null;
	}

	static private boolean CorrectParsing(String[] string_array)
	{
		String data = string_array[1];
		String ora = string_array[2];
		SimpleDateFormat formatter = new SimpleDateFormat("dd/MM/yyyy" + " " + "HH:mm", Locale.getDefault());

		try {
			formatter.parse(data + " " + ora);
			return true;
		} catch (ParseException e) {
			return false;
		}

	}
}
