package prova.med.activities;


import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;
import java.util.Locale;

import prova.med.NFCutils.NFCwriting;
import prova.med.boris.R;
import prova.med.db.RilevazioneDBAdapter;
import prova.med.obj.Rilevazione;
import android.nfc.NdefMessage;
import android.nfc.NdefRecord;
import android.nfc.NfcAdapter;
import android.nfc.Tag;
import android.os.Bundle;
import android.provider.Settings;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.PendingIntent;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.IntentFilter.MalformedMimeTypeException;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.Toast;
import android.support.v4.app.NavUtils;

public class NuovaRilevazione extends Activity {

	private RilevazioneDBAdapter datasource;
	private String codice_a_barre;
	private NfcAdapter nfc_adapter = null;
	private PendingIntent pending_intent;
	private IntentFilter writeTagFilters[];
	private Tag detectedTag;
	private EditText editText_fr, editText_so2, editText_pa, editText_fc;
	private NdefMessage msg_nfc;
	private Context context = this;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_nuova_rilevazione);
		
		// Show the Up button in the action bar.
		setupActionBar();
		
		Intent intent = getIntent();
		codice_a_barre = intent.getStringExtra(getString(R.string.IntentCodBarre));
		datasource = new RilevazioneDBAdapter(getApplicationContext());

		//recupero le editext da controllare per velocizzare controlli
		editText_fr = (EditText)findViewById(R.id.EditTextfr);
		editText_so2 = (EditText)findViewById(R.id.EditTextSo2);
		editText_pa = (EditText)findViewById(R.id.EditTextpa);
		editText_fc = (EditText)findViewById(R.id.EditTextfc);
		//recupero nfc adapter
		nfc_adapter = NfcAdapter.getDefaultAdapter(this);

		pending_intent = PendingIntent.getActivity(this, 0, new Intent(this, getClass()).addFlags(Intent.FLAG_ACTIVITY_SINGLE_TOP), 0); 

		//IntentFilter discovery = new IntentFilter(NfcAdapter.ACTION_TAG_DISCOVERED);  
		IntentFilter ndefDetected = new IntentFilter(NfcAdapter.ACTION_NDEF_DISCOVERED);      
		//IntentFilter techDetected = new IntentFilter(NfcAdapter.ACTION_TECH_DISCOVERED);  
		// Intent filters for writing to a tag
		try {
			ndefDetected.addDataType("text/plain");
		}
		catch (MalformedMimeTypeException e) {
			throw new RuntimeException("fail", e);
		}
		writeTagFilters = new IntentFilter[] { ndefDetected };  
	}

	/**
	 * Set up the {@link android.app.ActionBar}.
	 */
	private void setupActionBar() {

		getActionBar().setDisplayHomeAsUpEnabled(true);

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		if(NfcAdapter.getDefaultAdapter(this) != null)
			getMenuInflater().inflate(R.menu.nuova_rilevazione_with_nfc, menu);
		else
			getMenuInflater().inflate(R.menu.nuova_rilevazione_without_nfc, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case android.R.id.home:
			// This ID represents the Home or Up button. In the case of this
			// activity, the Up button is shown. Use NavUtils to allow users
			// to navigate up one level in the application structure. For
			// more details, see the Navigation pattern on Android Design:
			//
			// http://developer.android.com/design/patterns/navigation.html#up-vs-back
			//
			NavUtils.navigateUpFromSameTask(this);
			return true;
		case R.id.openWirelessSettings:
			startActivity(new Intent(Settings.ACTION_WIRELESS_SETTINGS));  
			return true;
		}
		return super.onOptionsItemSelected(item);
	}

	public void salvaRilevazione(View v)
	{
		v.setClickable(false);

		if(someNecessaryFieldsNotFilled())
			Toast.makeText(this, getString(R.string.campinoncompleti), Toast.LENGTH_SHORT).show();
		else 
		{
			
			Rilevazione rilevazione = fillRilevazione();
			if(datasource.createRilevazione(rilevazione, codice_a_barre) > -1 )
			{
				Toast.makeText(this, getString(R.string.rilevazionesalvata), Toast.LENGTH_SHORT).show();
				if(nfc_adapter != null && nfc_adapter.isEnabled())
				{
					
					NdefRecord record_codice = NFCwriting.createRecord(codice_a_barre);
					NdefRecord record_data = NFCwriting.createRecord(rilevazione.getData());
					NdefRecord record_ora = NFCwriting.createRecord(rilevazione.getOra());
					msg_nfc = new NdefMessage(new NdefRecord[] {record_codice, record_data, record_ora});
					askUserToWriteNFC();
				}
				else
					finish();


			}
			else
			{
				Toast.makeText(this, "Errore durante l'inserimento. Riprovare", Toast.LENGTH_SHORT).show();

			}
		}

		v.setClickable(true);
	}


	@Override
	protected void onResume() {
		datasource.open();
		super.onResume();
		if( nfc_adapter != null) 
		{
			nfc_adapter.enableForegroundDispatch(this, pending_intent, writeTagFilters, null); 
			if(!nfc_adapter.isEnabled())
				this.askUserToActivateNfc();
		}

	}

	@Override
	protected void onPause() {
		datasource.close();
		if(nfc_adapter != null) 
			nfc_adapter.disableForegroundDispatch(this);
		super.onPause();
	}

	@Override  
	protected void onNewIntent(Intent intent) {  
		super.onNewIntent(intent);            
		if(NfcAdapter.ACTION_NDEF_DISCOVERED.equals(intent.getAction())) {  
			// validate that this tag can be written  
			detectedTag = intent.getParcelableExtra(NfcAdapter.EXTRA_TAG);  

		}  
	}  


	private Rilevazione fillRilevazione()
	{
		Date time = Calendar.getInstance().getTime();
		SimpleDateFormat format_data = new SimpleDateFormat("dd/MM/yyyy", Locale.getDefault());
		SimpleDateFormat format_ora = new SimpleDateFormat("HH:mm", Locale.getDefault());
		Rilevazione rilevazione = new Rilevazione(format_data.format(time), format_ora.format(time));

		rilevazione.setSvs_riposo(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerSVS_RIP)).getSelectedItem().toString()));
		rilevazione.setSvs_sforzo(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerSVS_SFO)).getSelectedItem().toString()));
		rilevazione.setVas_sforzo(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerVAS_RIP)).getSelectedItem().toString()));
		rilevazione.setVas_sforzo(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerVAS_SFO)).getSelectedItem().toString()));

		rilevazione.setSede(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerSede)).getSelectedItem().toString()));
		rilevazione.setSedazione(Integer.parseInt(((Spinner)findViewById(R.id.SpinnerSedazione)).getSelectedItem().toString()));

		rilevazione.setFr(Integer.parseInt (editText_fr.getText().toString().trim()) );
		rilevazione.setSo2(Integer.parseInt (((EditText)findViewById(R.id.EditTextSo2)).getText().toString()) );
		rilevazione.setPa(Integer.parseInt (((EditText)findViewById(R.id.EditTextpa)).getText().toString()) );
		rilevazione.setFc(Integer.parseInt (((EditText)findViewById(R.id.EditTextfc)).getText().toString()) );
		rilevazione.setEffetti_avversi( ((EditText)findViewById(R.id.EditTextEffettiAvversi)).getText().toString() );
		rilevazione.setNote( ((EditText)findViewById(R.id.EditTextNote)).getText().toString() );


		return rilevazione;
	}

	private boolean someNecessaryFieldsNotFilled()
	{
		return editText_fr.getText().toString().trim().isEmpty() || 
				editText_so2.getText().toString().trim().isEmpty() ||
				editText_pa.getText().toString().trim().isEmpty() ||
				editText_fc.getText().toString().trim().isEmpty();
	}

	private void askUserToActivateNfc(){
		AlertDialog.Builder builder = new AlertDialog.Builder(context);
		builder.setMessage(getResources().getString(R.string.attivarenfc))
		.setPositiveButton(getResources().getString(R.string.si), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {

				startActivity(new Intent(Settings.ACTION_WIRELESS_SETTINGS));  
			}
		})
		.setNegativeButton(getResources().getString(R.string.no), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				dialog.cancel();
			}
		})
		.setOnCancelListener(new DialogInterface.OnCancelListener() {
			public void onCancel(DialogInterface dialog) {
				return;
			}
		});

		AlertDialog alert = builder.create();
		alert.show();
	}

	private void askUserToWriteNFC()
	{
		AlertDialog.Builder builder = new AlertDialog.Builder(context);
		builder.setCancelable(false)
		.setMessage(getResources().getString(R.string.scritturanfc))
		.setPositiveButton(getResources().getString(R.string.si), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				String esito = NFCwriting.writeNdefMessageToTag(msg_nfc, detectedTag);
				if(esito.equals(NFCwriting.successo))
				{
					finish();
				}
				else
					askUserToRetryNFCWriting(esito);
			}
		})
		.setNegativeButton(getResources().getString(R.string.no), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				finish();
			}
		});

		AlertDialog alert = builder.create();
		alert.show();
	}
	private void askUserToRetryNFCWriting(String error)
	{
		
		AlertDialog.Builder builder = new AlertDialog.Builder(context);
		builder.setCancelable(false)
		.setMessage(getResources().getString(R.string.riprovare))
		.setTitle(error)
		.setPositiveButton(getResources().getString(R.string.si), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				String esito = NFCwriting.writeNdefMessageToTag(msg_nfc, detectedTag);
				if(esito.equals(NFCwriting.successo))
				{
					finish();
				}
				else
					askUserToRetryNFCWriting(esito);
			}
		})
		.setNegativeButton(getResources().getString(R.string.no), new DialogInterface.OnClickListener() {
			public void onClick(DialogInterface dialog, int id) {
				finish();
			}
		});

		AlertDialog alert = builder.create();
		alert.show();
	}
}
