package prova.med.activities;


import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Collections;
import java.util.Date;
import java.util.List;

import prova.med.NFCutils.NFCreading;
import prova.med.boris.R;
import prova.med.db.PazientiDBAdapter;
import prova.med.db.RilevazioneDBAdapter;
import prova.med.listviewadapters.ArrayRilevazioneAdapter;
import prova.med.obj.Paziente;
import prova.med.obj.Rilevazione;
import android.nfc.NdefMessage;
import android.nfc.NfcAdapter;
import android.os.AsyncTask;
import android.os.Bundle;
import android.app.Activity;
import android.app.AlertDialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import android.support.v4.app.NavUtils;

public class ScanNFC extends Activity {

	private TextView textView_codice_a_barre, textView_nomecognome, textView_data, textView_ora, textView_protocollo;
	private boolean managing_intent = true;
	private String codice_a_barre, data, ora;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_scan_nfc);
		setupActionBar();

		textView_codice_a_barre = (TextView) findViewById(R.id.textViewCodiceBarrevalue);
		textView_nomecognome = (TextView) findViewById(R.id.textViewNomeCognome);
		textView_data = (TextView) findViewById(R.id.textViewUltimaDatavalue);
		textView_ora = (TextView) findViewById(R.id.textViewUltimaOravalue);
		textView_protocollo = (TextView) findViewById(R.id.textViewProtocollo);
		handleintent(getIntent());
	}


	/**
	 * Set up the {@link android.app.ActionBar}.
	 */
	private void setupActionBar() {

		getActionBar().setDisplayHomeAsUpEnabled(true);

	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.test_nfc_read, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case android.R.id.home:
			// This ID represents the Home or Up button. In the case of this
			// activity, the Up button is shown. Use NavUtils to allow users
			// to navigate up one level in the application structure. For
			// more details, see the Navigation pattern on Android Design:
			//
			// http://developer.android.com/design/patterns/navigation.html#up-vs-back
			//
			NavUtils.navigateUpFromSameTask(this);
			return true;
		case R.id.aggiungirilevazioneNFC:
			if (textView_codice_a_barre.getText().toString() != null && !textView_codice_a_barre.getText().toString().isEmpty())
			{
				if(oraNonPassata())
				{
					AlertDialog.Builder builder = new AlertDialog.Builder(this);
					builder.setMessage(getResources().getString(R.string.ultimarilevazionerecente))
					.setPositiveButton(getResources().getString(R.string.si), new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {

							Intent intent = new Intent(getApplicationContext(), NuovaRilevazione.class);
							intent.putExtra( getString(R.string.IntentCodBarre), textView_codice_a_barre.getText().toString());
							startActivity(intent);
						}
					})
					.setNegativeButton(getResources().getString(R.string.no), new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int id) {
							dialog.cancel();
						}
					})
					.setOnCancelListener(new DialogInterface.OnCancelListener() {
						public void onCancel(DialogInterface dialog) {
							return;
						}
					});

					AlertDialog alert = builder.create();
					alert.show();
				}
				else
				{
					Intent intent = new Intent(this, NuovaRilevazione.class );
					intent.putExtra( getString(R.string.IntentCodBarre), textView_codice_a_barre.getText().toString());
					startActivity(intent);
				}
			}
			else
				Toast.makeText(this, "Effettuare prima la scansione NFC di un Tag valido", Toast.LENGTH_SHORT).show();
		}
		return super.onOptionsItemSelected(item);
	}


	private void handleintent(Intent intent)
	{
		if (NfcAdapter.ACTION_NDEF_DISCOVERED.equals(intent.getAction()) && "text/plain".equals(intent.getType() )) {
			NdefMessage[] messages = NFCreading.readNdefMessageFromTag(intent);
			
			String[] result = NFCreading.readRecordsFromMessage(messages[0]);
			if(result != null)
			{
				managing_intent = true;
				new AsyncTaskRecuperaInfo(this).execute(result);
			}
			else
				findViewById(R.id.textViewDatiNonPertinenti).setVisibility(View.VISIBLE);
		}
	}

	@Override
	protected void onResume() {

		super.onResume();
		if(!managing_intent && !textView_codice_a_barre.getText().toString().isEmpty())
		{
			new AsyncTaskRefreshInfo(this).execute(textView_codice_a_barre.getText().toString());
		}
		managing_intent = false;
	}

	private boolean oraNonPassata()
	{
		String data = textView_data.getText().toString().trim();
		String ora = textView_ora.getText().toString().trim();
		Calendar an_hour_ago = Calendar.getInstance();
		an_hour_ago.add(Calendar.HOUR_OF_DAY, -1);
		SimpleDateFormat formatter = new SimpleDateFormat("dd/MM/yyyy" + " " + "HH:mm");
		Date ultima_rilevazione;
		try {
			ultima_rilevazione = formatter.parse(data + " " + ora);
		} catch (ParseException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			return false;
		}
		return (ultima_rilevazione.after(an_hour_ago.getTime()));
	}


	private class AsyncTaskRecuperaInfo extends AsyncTask < String , Void , Boolean > {

		private ProgressDialog      progressDialog ;
		private Activity            targetActivity ;
		private Paziente p = null;
		private List<Rilevazione> rilevazioni = null;

		public AsyncTaskRecuperaInfo ( Activity activity ) {
			this.targetActivity = activity ;
			// this.needToShow = true;
			progressDialog = new ProgressDialog ( targetActivity ) ;
			progressDialog.setCancelable ( false ) ;
			progressDialog.setMessage ( getString(R.string.attendere) ) ;
			progressDialog.setTitle ( getString(R.string.recuperodati)) ;
			progressDialog.setIndeterminate ( true ) ;
		}

		@ Override
		protected void onPreExecute ( ) {
			progressDialog.show ( ); 
		}

		@ Override
		protected Boolean doInBackground ( String ... params) {

			codice_a_barre = params[0];
			data = params[1];
			ora = params[2];
			PazientiDBAdapter datasourcePazienti = new PazientiDBAdapter(getApplicationContext());
			RilevazioneDBAdapter datasourceRilevazioni = new RilevazioneDBAdapter(getApplicationContext());
			datasourcePazienti.open();
			p = datasourcePazienti.getPaziente(codice_a_barre);
			datasourcePazienti.close();

			datasourceRilevazioni.open();
			rilevazioni = datasourceRilevazioni.getRilevazioni(codice_a_barre);
			datasourceRilevazioni.close();
			if(p != null)
				return true;
			else
				return false ;
		}

		@ Override
		protected void onPostExecute (Boolean paziente_presente) {
			if(progressDialog != null && progressDialog.isShowing()){
				progressDialog.dismiss ( ) ;

				textView_codice_a_barre.setText(codice_a_barre);
				textView_data.setText(data);
				textView_ora.setText(ora);

				if(paziente_presente)
				{
					findViewById(R.id.LayoutPazientePresente).setVisibility(View.VISIBLE);

					textView_nomecognome.setText(p.getNome() +  " " + p.getCognome());
					textView_protocollo.setText(p.getNome_protocollo());
				}
				else{
					findViewById(R.id.textViewPazienteNonPresente).setVisibility(View.VISIBLE);
				}

				if(rilevazioni != null && !rilevazioni.isEmpty())
				{
					findViewById(R.id.textViewNessunaRilevazione).setVisibility(View.GONE);
					ListView listviewRilevazioni = (ListView)findViewById(R.id.ListViewRilevazioni);
					Collections.sort(rilevazioni);
					Collections.reverse(rilevazioni);
					ArrayRilevazioneAdapter arrayrilevazioneadapter = new ArrayRilevazioneAdapter(targetActivity, R.layout.rowrilevazione, rilevazioni);
					listviewRilevazioni.setAdapter(arrayrilevazioneadapter);
					listviewRilevazioni.setVisibility(View.VISIBLE);
					Rilevazione rilevazionescan = new Rilevazione(data, ora);
					Rilevazione rilevazioneheadlist = rilevazioni.get(0);
					if(rilevazionescan.compareTo(rilevazioneheadlist) < 0)
					{
						textView_data.setText(rilevazioneheadlist.getData());
						textView_ora.setText(rilevazioneheadlist.getOra());
					}
				}
				else
					findViewById(R.id.textViewNessunaRilevazione).setVisibility(View.VISIBLE);
			}

		}
	}


	private class AsyncTaskRefreshInfo extends AsyncTask < String , Void , List<Rilevazione> > {

		private ProgressDialog      progressDialog ;
		private Activity            targetActivity ;

		public AsyncTaskRefreshInfo ( Activity activity ) {
			this.targetActivity = activity ;
			// this.needToShow = true;
			progressDialog = new ProgressDialog ( targetActivity ) ;
			progressDialog.setCancelable ( false ) ;
			progressDialog.setMessage ( getString(R.string.attendere) ) ;
			progressDialog.setTitle ( getString(R.string.recuperodati)) ;
			progressDialog.setIndeterminate ( true ) ;
		}

		@ Override
		protected void onPreExecute ( ) {
			progressDialog.show ( ); 
		}

		@ Override
		protected List<Rilevazione> doInBackground ( String ... params) {

			RilevazioneDBAdapter datasourceRilevazioni = new RilevazioneDBAdapter(targetActivity);
			datasourceRilevazioni.open();
			List<Rilevazione> rilevazioni = datasourceRilevazioni.getRilevazioni(params[0]);
			datasourceRilevazioni.close();
			return rilevazioni;
		}

		@ Override
		protected void onPostExecute (List<Rilevazione> rilevazioni) {
			if(progressDialog != null && progressDialog.isShowing()){
				progressDialog.dismiss ( ) ;

				if(rilevazioni != null && !rilevazioni.isEmpty())
				{
					findViewById(R.id.textViewNessunaRilevazione).setVisibility(View.GONE);
					ListView listviewRilevazioni = (ListView)findViewById(R.id.ListViewRilevazioni);
					Collections.sort(rilevazioni);
					Collections.reverse(rilevazioni);
					ArrayRilevazioneAdapter arrayrilevazioneadapter = new ArrayRilevazioneAdapter(targetActivity, R.layout.rowrilevazione, rilevazioni);
					listviewRilevazioni.setAdapter(arrayrilevazioneadapter);
					listviewRilevazioni.setVisibility(View.VISIBLE);
					Rilevazione rilevazionescan = new Rilevazione(textView_data.getText().toString(), textView_ora.getText().toString());
					Rilevazione rilevazioneheadlist = rilevazioni.get(0);
					if(rilevazionescan.compareTo(rilevazioneheadlist) < 0)
					{
						textView_data.setText(rilevazioneheadlist.getData());
						textView_ora.setText(rilevazioneheadlist.getOra());
					}
				}
				else
					findViewById(R.id.textViewNessunaRilevazione).setVisibility(View.VISIBLE);
			}

		}
	}

}
