package prova.med.activities;

import android.os.Bundle;
import android.app.ActionBar;
import android.app.ActionBar.Tab;
import android.app.Activity;
import android.app.Fragment;
import android.app.FragmentTransaction;
import android.content.Intent;
import android.support.v4.app.NavUtils;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;
import prova.med.boris.R;
import prova.med.frag.AbstractProtocolloFrag;
import prova.med.frag.ProtocolloAFrag;
import prova.med.frag.ProtocolloBFrag;
import prova.med.frag.ProtocolloCFrag;
import prova.med.frag.ProtocolloDFrag;
import prova.med.obj.*;
public class TabProtocollo extends Activity {

	private Paziente paziente;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.activity_tab_protocollo);
		
		//prendere il paziente dall'intent
		Intent intent = getIntent();
		paziente = (Paziente) intent.getSerializableExtra(getString(R.string.IntentPaziente));
		
		//creo tab
		setupActionbar();
	}

	private void setupActionbar()
	{
		//inizializzazione e aggiunta tab dei protocolli
		//label del tab -> tag del fragment
		ActionBar actionBar = getActionBar(); 
		actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_TABS); 
		String label1 = getResources().getString(R.string.protA); 
		Tab tab = actionBar.newTab(); 
		tab.setText(label1);
		TabListener<ProtocolloAFrag> tl = new TabListener<ProtocolloAFrag>(this, label1, ProtocolloAFrag.class); 
		tab.setTabListener(tl); 
		actionBar.addTab(tab); 

		String label2 = getResources().getString(R.string.protB); 
		tab = actionBar.newTab(); 
		tab.setText(label2); 
		TabListener<ProtocolloBFrag> tl2 = new TabListener<ProtocolloBFrag>(this, label2, ProtocolloBFrag.class); 
		tab.setTabListener(tl2); 
		actionBar.addTab(tab); 
		
		String label3 = getResources().getString(R.string.protC); 
		tab = actionBar.newTab(); 
		tab.setText(label3); 
		TabListener<ProtocolloCFrag> tl3 = new TabListener<ProtocolloCFrag>(this, label3, ProtocolloCFrag.class); 
		tab.setTabListener(tl3); 
		actionBar.addTab(tab);
		
		String label4 = getResources().getString(R.string.protD); 
		tab = actionBar.newTab(); 
		tab.setText(label4); 
		TabListener<ProtocolloDFrag> tl4 = new TabListener<ProtocolloDFrag>(this, label4, ProtocolloDFrag.class); 
		tab.setTabListener(tl4); 
		actionBar.addTab(tab); 
		
	}
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.tab_protocollo, menu);
		return true;
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case android.R.id.home:
			// This ID represents the Home or Up button. In the case of this
			// activity, the Up button is shown. Use NavUtils to allow users
			// to navigate up one level in the application structure. For
			// more details, see the Navigation pattern on Android Design:
			//
			// http://developer.android.com/design/patterns/navigation.html#up-vs-back
			//
			NavUtils.navigateUpFromSameTask(this);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}

	private class TabListener<T extends Fragment> implements ActionBar.TabListener { 
		private Fragment mFragment; 
		private final Activity mActivity; 
		private final String mTag; 
		private final Class<T> mClass; 
		public TabListener(Activity activity, String tag, Class<T> clz) { 
			mActivity = activity; 
			mTag = tag; 
			mClass = clz; 
		} 
		public void onTabSelected(Tab tab, FragmentTransaction ft) { 
			if (mFragment == null) { 
				mFragment = Fragment.instantiate(mActivity, mClass.getName()); 
				ft.add(android.R.id.content, mFragment, mTag); 
			} else { 
				ft.attach(mFragment); 
			} 
		} 
		public void onTabUnselected(Tab tab, FragmentTransaction ft) { 
			if (mFragment != null) { 
				ft.detach(mFragment); 
			} 
		} 
		public void onTabReselected(Tab tab, FragmentTransaction ft) {  
			// User selected the already selected tab. Usually do nothing. 
		} 
	}

	
	public void createProtocol(View v)
	{
		//prevengo click multipli
		v.setClickable(false);
		
		//estrazione protocollo
		AbstractProtocolloFrag frag = (AbstractProtocolloFrag) getFragmentManager().findFragmentByTag(getActionBar().getSelectedTab().getText().toString());
		String campi_corretti = frag.checkFields();
		if(!campi_corretti.equals(AbstractProtocolloFrag.SUCCESS))
		{
			Toast.makeText(this, campi_corretti, Toast.LENGTH_SHORT).show();
			v.setClickable(true);
			return;
		}
		AbstractProtocollo prot = frag.createProtocol();
		paziente.setNome_protocollo( prot.getClass().getSimpleName());

		//scrittura 
		if(frag.savePazienteProtocollo(paziente, prot))
		{
			//Paziente inserito correttamente: lancio intent e torno alla schermata inziale
			Intent intent = new Intent(this, MainActivity.class);
			intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP); 
			intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
			v.setClickable(true);
			Toast.makeText(this, getString(R.string.pazientesalvatocorrettamente), Toast.LENGTH_SHORT).show();
			startActivity(intent);
		}
		
		else
		{
			Toast.makeText(this, "Inserimento errato. Riprova", Toast.LENGTH_SHORT).show();
			v.setClickable(true);
		}
	}
	

}
