package prova.med.db;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import prova.med.obj.Paziente;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class PazientiDBAdapter {

	public static final String ROW_ID_TABLE_PAZIENTI = "_id";
	public static final String NOME = "nome";	//1
	public static final String COGNOME = "cognome";	//2
	public static final String INGRESSO = "ingresso";	//3
	public static final String NLETTO = "nletto";	//4
	public static final String REPARTO = "reparto";
	public static final String PIANO = "piano";
	public static final String CODINTERVENTO = "codintervento";
	public static final String CODDIAGNOSI = "coddiagnosi";
	public static final String PATOLOGIA = "patologia";
	public static final String ALLERGIE = "allergie";
	public static final String ALLERGIEALTRO = "allergiealtro";
	public static final String CODBARRE = "codbarre";	//12
	public static final String CREATININA = "creatinina";
	public static final String ALT = "alt";
	public static final String AST = "ast";
	public static final String ANNI = "anni";
	public static final String PROTOCOLLO = "protocollo";
	public static final String ULTIMA_MODIFICA = "ultima_modifica";	//18

	public static final String DATABASE_TABLE_PAZIENTI = "pazienti";
	public static final String DATABASE_TABLE_PAZIENTI_CANCELLATI = "pazienticancellati";
	protected DatabaseHelper mDbHelper;
	protected SQLiteDatabase mDb;
	protected final Context mCtx;

	protected static class DatabaseHelper extends SQLiteOpenHelper {

		DatabaseHelper(Context context) {
			super(context, DBAdapter.DATABASE_NAME, null, DBAdapter.DATABASE_VERSION);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		}
	}

	public PazientiDBAdapter(Context ctx) {
		this.mCtx = ctx;
	}

	/**
	 * Open the pazienti database. If it cannot be opened, try to create a new
	 * instance of the database. If it cannot be created, throw an exception to
	 * signal the failure
	 * 
	 * @return this (self reference, allowing this to be chained in an
	 *         initialization call)
	 * @throws SQLException
	 *             if the database could be neither opened or created
	 */
	public PazientiDBAdapter open() throws SQLException {
		this.mDbHelper = new DatabaseHelper(this.mCtx);
		this.mDb = this.mDbHelper.getWritableDatabase();
		return this;
	}

	/**
	 * close return type: void
	 */
	public void close() {
		this.mDbHelper.close();
	}

	/**
	 * Create a new paziente. If the paziente is successfully created return the new
	 * rowId for that paziente, otherwise return a -1 to indicate failure.
	 * @param paziente TODO
	 * 
	 * @return rowId or -1 if failed
	 */
	protected long createPaziente(Paziente paziente) {

		ContentValues initialValues = new ContentValues();
		initialValues.put(NOME, paziente.getNome());
		initialValues.put(COGNOME, paziente.getCognome());
		initialValues.put(INGRESSO, paziente.getData_di_ingresso());
		initialValues.put(NLETTO, paziente.getNumero_letto());
		initialValues.put(REPARTO, paziente.getReparto());
		initialValues.put(PIANO, paziente.getPiano());
		initialValues.put(CODINTERVENTO, paziente.getCodice_intervento());
		initialValues.put(CODDIAGNOSI, paziente.getCodice_diagnosi());
		initialValues.put(PATOLOGIA, paziente.getPatologia());
		initialValues.put(ALLERGIE, paziente.getAllergie());
		initialValues.put(ALLERGIEALTRO, paziente.getAllergie_altro());
		initialValues.put(CODBARRE, paziente.getCodice_a_barre());
		initialValues.put(CREATININA, paziente.getCreatinina());
		initialValues.put(ALT, paziente.getAlt());
		initialValues.put(AST, paziente.getAst());
		initialValues.put(ANNI, paziente.getAnni());
		initialValues.put(PROTOCOLLO, paziente.getNome_protocollo());
		return this.mDb.insert(DATABASE_TABLE_PAZIENTI, null, initialValues);
	}

	public boolean codeAlreadyUsed(String codice_a_barre)
	{
		Cursor mCursor = this.mDb.query(true, DATABASE_TABLE_PAZIENTI, null, CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null);

		return mCursor.moveToFirst();
	}

	/**
	 * Cancella il paziente avente il codice a barre fornito
	 * @param stringa del codice a barre
	 * @return true se delete avvenuta, false altrimenti
	 */
	public boolean deletePaziente(String cod_barre) {
		int result = 0;
		mDb.beginTransaction();
		try {
			result = this.mDb.delete(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA, CODBARRE + " =?", new String[]{cod_barre}) +
					this.mDb.delete(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB, CODBARRE + " =?", new String[]{cod_barre}) +
					this.mDb.delete(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC, CODBARRE + " =?", new String[]{cod_barre}) +
					this.mDb.delete(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD, CODBARRE + " =?", new String[]{cod_barre}) +
					this.mDb.delete(RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI, CODBARRE + " =?", new String[]{cod_barre}) +
					this.mDb.delete(DATABASE_TABLE_PAZIENTI, CODBARRE + " =?", new String[]{cod_barre});

			ContentValues initialValues = new ContentValues();
			initialValues.put(CODBARRE, cod_barre);
			this.mDb.insert(DATABASE_TABLE_PAZIENTI_CANCELLATI, null, initialValues);
			
			mDb.setTransactionSuccessful();
		}catch (Exception e)
		{
			result = -1;

		}finally {
			mDb.endTransaction();
		}

		return result > 0;
	}

	public void deletePazientiCancellati(String data) 
	{
		this.mDb.delete(DATABASE_TABLE_PAZIENTI_CANCELLATI, ULTIMA_MODIFICA + " <?", new String[]{data});
	}
	/**
	 * Restitusce la lista di tutti i pazienti presenti in un piano
	 * @param nome del piano
	 * @return List<Paziente>, lista vuota altrimenti
	 */
	public List<Paziente> getAllPazienti(String piano) {

		List<Paziente> pazienti = new ArrayList<Paziente>();

		Cursor cursor = this.mDb.query(DATABASE_TABLE_PAZIENTI, null, PIANO + "=?", new String[] { piano },  null, null, null);

		cursor.moveToFirst();
		while (!cursor.isAfterLast()) {
			Paziente p = cursorToPaziente(cursor);
			pazienti.add(p);
			cursor.moveToNext();
		}
		// make sure to close the cursor
		cursor.close();
		return pazienti;
	}

	/**
	 * Restituisce il paziente avente il codice a barre fornito
	 * @param Stringa del codice a barre
	 * @return Il paziente avente il codice a barre, null altrimenti
	 */
	public Paziente getPaziente(String codice_a_barre){

		Cursor mCursor = this.mDb.query(true, DATABASE_TABLE_PAZIENTI, null, CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null);

		if(mCursor.moveToFirst())
		{
			Paziente p = cursorToPaziente(mCursor);
			mCursor.close();
			return p;
		}
		mCursor.close();
		return null;
	}

	/**
	 * Update Paziente
	 * @return true if the note was successfully updated, false otherwise
	 */
	public boolean updatePaziente(Paziente paziente) {
		ContentValues args = new ContentValues();
		args.put(NOME, paziente.getNome());
		args.put(COGNOME, paziente.getCognome());
		args.put(INGRESSO, paziente.getData_di_ingresso());
		args.put(NLETTO, paziente.getNumero_letto());
		args.put(REPARTO, paziente.getReparto());
		args.put(PIANO, paziente.getPiano());
		args.put(CODINTERVENTO, paziente.getCodice_intervento());
		args.put(CODDIAGNOSI, paziente.getCodice_diagnosi());
		args.put(PATOLOGIA, paziente.getPatologia());
		args.put(ALLERGIE, paziente.getAllergie());
		args.put(ALLERGIEALTRO, paziente.getAllergie_altro());
		args.put(CODBARRE, paziente.getCodice_a_barre());
		args.put(CREATININA, paziente.getCreatinina());
		args.put(ALT, paziente.getAlt());
		args.put(AST, paziente.getAst());
		args.put(ANNI, paziente.getAnni());
		SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss", Locale.getDefault());
		Date date = Calendar.getInstance().getTime();
		args.put(ULTIMA_MODIFICA, dateFormat.format(date)); 

		return this.mDb.update(DATABASE_TABLE_PAZIENTI, args, CODBARRE + "=" + paziente.getCodice_a_barre(), null) >0; 
	}

	protected Paziente cursorToPaziente(Cursor cursor) {
		Paziente paziente = new Paziente();
		paziente.setNome(cursor.getString(1));
		paziente.setCognome(cursor.getString(2));
		paziente.setData_di_ingresso(cursor.getString(3));
		paziente.setNumero_letto(cursor.getString(4));
		paziente.setReparto(cursor.getString(5));
		paziente.setPiano(cursor.getString(6));
		paziente.setCodice_intervento(cursor.getString(7));
		paziente.setCodice_diagnosi(cursor.getString(8));
		paziente.setPatologia(cursor.getString(9));
		paziente.setAllergie(cursor.getString(10));
		paziente.setAllergie_altro(cursor.getString(11));
		paziente.setCodice_a_barre(cursor.getString(12));
		paziente.setCreatinina(cursor.getString(13));
		paziente.setAlt(cursor.getString(14));
		paziente.setAst(cursor.getString(15));
		paziente.setAnni(cursor.getString(16));
		paziente.setNome_protocollo(cursor.getString(17));
		return paziente;
	}



}