package prova.med.db;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import prova.med.obj.AbstractProtocollo;
import prova.med.obj.FarmacoPos;
import prova.med.obj.Gastroprotezione;
import prova.med.obj.Paziente;
import prova.med.obj.Ponv;
import prova.med.obj.ProtocolloA;
import prova.med.obj.Rescue;

public class ProtocolloADBAdapter extends PazientiDBAdapter implements IProtocolloDBAdapter{

	public static final String ROW_ID_TABLE_PROTOCOLLOA = "_id";	//0	  	
	// CODBARRE 1
	public static final String FARMACO1_NOME = "farmaco1nome"; //2
	public static final String FARMACO1_POS = "farmaco1pos";	//3
	public static final String FARMACO2_NOME = "farmaco2nome";	//4
	public static final String FARMACO2_POS = "farmaco2pos";	//5
	public static final String RESCUE_NOME = "rescuenome";	//6
	public static final String RESCUE_POS = "rescuepos";	//7
	public static final String GASTRO_NOME = "gastronome";	//8
	public static final String GASTRO_DOSE = "gastrodose";	//9
	public static final String PONV_NOME = "ponvnome";	//10
	public static final String PONV_POS = "ponvpos";	//11
	public static final String PONV_DOSE = "ponvdose";	//12
	public static final String DATABASE_TABLE_PROTOCOLLOA = "protocolloa";
	
	public ProtocolloADBAdapter(Context ctx) {
		super(ctx);
		// TODO Auto-generated constructor stub
	}

	@Override
	public boolean updateProtocollo(AbstractProtocollo protocollo, String codice_a_barre) {
		
		ContentValues args = new ContentValues();
		ProtocolloA p = (ProtocolloA) protocollo;
	    args.put(CODBARRE, codice_a_barre);
	    args.put(FARMACO1_NOME, p.getFarmacopos1().getNome());
	    args.put(FARMACO1_POS, p.getFarmacopos1().getPosologia());
	    args.put(FARMACO2_NOME, p.getFarmacopos2().getNome());
	    args.put(FARMACO2_POS, p.getFarmacopos2().getPosologia());
	    args.put(RESCUE_NOME, p.getRescue().getNome());
	    args.put(RESCUE_POS, p.getRescue().getPosologia());
	    args.put(GASTRO_NOME, p.getGastro().getNome());
	    args.put(GASTRO_DOSE, p.getGastro().getDosaggio());
	    args.put(PONV_NOME, p.getPonv().getNome());
	    args.put(PONV_POS, p.getPonv().getPosologia());
	    args.put(PONV_DOSE, p.getPonv().getDosaggio());
	    
	    return this.mDb.update(DATABASE_TABLE_PROTOCOLLOA, args, CODBARRE + " =?" ,new String[]{codice_a_barre}) >0;
	}

	@Override
	public AbstractProtocollo getProtocollo(String codice_a_barre) {
		
		ProtocolloA protocollo = null;
		Cursor mCursor =    this.mDb.query(true, DATABASE_TABLE_PROTOCOLLOA, null, CODBARRE + " =?" ,new String[]{ codice_a_barre}, null, null, null, null);
		
		if(mCursor.moveToFirst())
		{
			protocollo = cursorToProtocollo(mCursor);
		}
		mCursor.close();
		return protocollo;
	}

	@Override
	public boolean createPazienteAndProtocollo(Paziente paz, AbstractProtocollo prot) {
		boolean success = false;
		mDb.beginTransaction();
        try {
        	long inserimentopaziente = createPaziente(paz);
        	long inserimentoprotocollo = createProtocollo((ProtocolloA)prot, paz.getCodice_a_barre());
        	
        	if(inserimentopaziente != -1 && inserimentoprotocollo != -1)
        	{
        		mDb.setTransactionSuccessful();
        		success= true;
        	}
        }catch (Exception e)
        {
        	success = false;
        	
        }finally {
        	mDb.endTransaction();
        }

    	return success;
	}
	
	private ProtocolloA cursorToProtocollo(Cursor cursor) {
		ProtocolloA protocollo = new ProtocolloA();
		protocollo.setFarmacopos1(new FarmacoPos(cursor.getString(2), cursor.getString(3)));
		protocollo.setFarmacopos2(new FarmacoPos(cursor.getString(4), cursor.getString(5)));
		protocollo.setRescue(new Rescue(cursor.getString(6), cursor.getString(7)));
		protocollo.setGastro(new Gastroprotezione(cursor.getString(8), cursor.getString(9)));
		protocollo.setPonv(new Ponv(cursor.getString(10), cursor.getString(11), cursor.getString(12)));	
		return protocollo;
	}
	
	private long createProtocollo(ProtocolloA protocollo, String codice_a_barre) {
		
	    ContentValues initialValues = new ContentValues();
	    initialValues.put(CODBARRE, codice_a_barre);
	    initialValues.put(FARMACO1_NOME, protocollo.getFarmacopos1().getNome());
	    initialValues.put(FARMACO1_POS, protocollo.getFarmacopos1().getPosologia());
	    initialValues.put(FARMACO2_NOME, protocollo.getFarmacopos2().getNome());
	    initialValues.put(FARMACO2_POS, protocollo.getFarmacopos2().getPosologia());
	    initialValues.put(RESCUE_NOME, protocollo.getRescue().getNome());
	    initialValues.put(RESCUE_POS, protocollo.getRescue().getPosologia());
	    initialValues.put(GASTRO_NOME, protocollo.getGastro().getNome());
	    initialValues.put(GASTRO_DOSE, protocollo.getGastro().getDosaggio());
	    initialValues.put(PONV_NOME, protocollo.getPonv().getNome());
	    initialValues.put(PONV_POS, protocollo.getPonv().getPosologia());
	    initialValues.put(PONV_DOSE, protocollo.getPonv().getDosaggio());
	    
	    return this.mDb.insert(DATABASE_TABLE_PROTOCOLLOA, null, initialValues);
	}

}
