package prova.med.db;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import prova.med.obj.AbstractProtocollo;
import prova.med.obj.FarmacoDos;
import prova.med.obj.Gastroprotezione;
import prova.med.obj.Paziente;
import prova.med.obj.Ponv;
import prova.med.obj.ProtocolloC;
import prova.med.obj.Rescue;

public class ProtocolloCDBAdapter extends PazientiDBAdapter implements
		IProtocolloDBAdapter {
	// COLONNA e SUO INDEX
	public static final String ROW_ID_TABLE_PROTOCOLLOA = "_id";	//0	  	
	// CODBARRE 1
	public static final String FARMACO1_NOME = "farmaco1nome"; //2
	public static final String FARMACO1_DOSE = "farmaco1dose";	//3
	public static final String FARMACO2_NOME = "farmaco2nome";	//4
	public static final String FARMACO2_DOSE = "farmaco2dose";	//5
	public static final String SOL_FISIOLOGICA = "solfisiologica";	//6
	public static final String VOLUME_TOTALE = "volumetotale";	//7
	public static final String RESCUE_NOME = "rescuenome";	//8
	public static final String RESCUE_POS = "rescuepos";	//9
	public static final String INFUSIONE_CONTINUA = "infusionecontinua";
	public static final String DOSE_BOLO = "dosebolo";
	public static final String TEMPO_BLOCCO = "tempoblocco";
	public static final String TEMPO_LIMITE = "tempolimite";
	public static final String DOSE_TOTALE = "dosetotale";
	public static final String INTEGRA = "integraparacetamolo";	//15
	public static final String GASTRO_NOME = "gastronome";
	public static final String GASTRO_DOSE = "gastrodose";
	public static final String PONV_NOME = "ponvnome";
	public static final String PONV_POS = "ponvpos";
	public static final String PONV_DOSE = "ponvdose";	//20
	
	public static final String DATABASE_TABLE_PROTOCOLLOC = "protocolloc";
	
	public ProtocolloCDBAdapter(Context ctx) {
		super(ctx);
	}

	@Override
	public boolean createPazienteAndProtocollo(Paziente paz, AbstractProtocollo prot) {
		boolean success = false;
		mDb.beginTransaction();
        try {
        	long inserimentopaziente = createPaziente(paz);
        	long inserimentoprotocollo = createProtocollo((ProtocolloC)prot, paz.getCodice_a_barre());
        	
        	if(inserimentopaziente != -1 && inserimentoprotocollo != -1)
        	{
        		mDb.setTransactionSuccessful();
        		success = true;
        	}
        }catch (Exception e)
        {
        	success = false;
            //Error in between database transaction 
        }finally {
        	mDb.endTransaction();

        }
		return success;
	}

	@Override
	public AbstractProtocollo getProtocollo(String codice_a_barre) {

		ProtocolloC protocollo = null;
		Cursor mCursor =    this.mDb.query(true, DATABASE_TABLE_PROTOCOLLOC, null, CODBARRE + " = ?" ,new String[]{ codice_a_barre}, null, null, null, null);
		
		if(mCursor.moveToFirst())
		{
			protocollo = cursorToProtocollo(mCursor);
		}
		mCursor.close();
		return protocollo;
	}

	@Override
	public boolean updateProtocollo(AbstractProtocollo protocollo,
			String codice_a_barre) {
		ProtocolloC p = (ProtocolloC) protocollo;
		ContentValues args = new ContentValues();
	    args.put(CODBARRE, codice_a_barre);
	    args.put(FARMACO1_NOME, p.getFarmaco().getNome());
	    args.put(FARMACO1_DOSE, p.getFarmaco().getDosaggio());
	    args.put(FARMACO2_NOME, p.getAltro_farmaco().getNome());
	    args.put(FARMACO2_DOSE, p.getAltro_farmaco().getDosaggio());
	    args.put(SOL_FISIOLOGICA, p.getSol_fisiologica());
	    args.put(VOLUME_TOTALE, p.getVolume_totale());
	    args.put(RESCUE_NOME, p.getRescue().getNome());
	    args.put(RESCUE_POS, p.getRescue().getPosologia());
	    args.put(INFUSIONE_CONTINUA, p.getInfusione_continua());
	    args.put(DOSE_BOLO, p.getDose_bolo());
	    args.put(TEMPO_BLOCCO, p.getTempo_blocco());
	    args.put(TEMPO_LIMITE, p.getLimite_ore());
	    args.put(DOSE_TOTALE, p.getDose_totale());
	    args.put(INTEGRA, fromBooleanToInt(p.getIntegra_paracetamolo()));
	    args.put(GASTRO_NOME, p.getGastro().getNome());
	    args.put(GASTRO_DOSE, p.getGastro().getDosaggio());
	    args.put(PONV_NOME, p.getPonv().getNome());
	    args.put(PONV_POS, p.getPonv().getPosologia());
	    args.put(PONV_DOSE, p.getPonv().getDosaggio());
	    
	    return this.mDb.update(DATABASE_TABLE_PROTOCOLLOC, args, CODBARRE + " =?" ,new String[]{codice_a_barre}) >0;

	}

	private long createProtocollo(ProtocolloC protocollo, String codice_a_barre) {
		
	    ContentValues initialValues = new ContentValues();
	    initialValues.put(CODBARRE, codice_a_barre);
	    initialValues.put(FARMACO1_NOME, protocollo.getFarmaco().getNome());
	    initialValues.put(FARMACO1_DOSE, protocollo.getFarmaco().getDosaggio());
	    initialValues.put(FARMACO2_NOME, protocollo.getAltro_farmaco().getNome());
	    initialValues.put(FARMACO2_DOSE, protocollo.getAltro_farmaco().getDosaggio());
	    initialValues.put(SOL_FISIOLOGICA, protocollo.getSol_fisiologica());
	    initialValues.put(VOLUME_TOTALE, protocollo.getVolume_totale());
	    initialValues.put(RESCUE_NOME, protocollo.getRescue().getNome());
	    initialValues.put(RESCUE_POS, protocollo.getRescue().getPosologia());
	    initialValues.put(INFUSIONE_CONTINUA, protocollo.getInfusione_continua());
	    initialValues.put(DOSE_BOLO, protocollo.getDose_bolo());
	    initialValues.put(TEMPO_BLOCCO, protocollo.getTempo_blocco());
	    initialValues.put(TEMPO_LIMITE, protocollo.getLimite_ore());
	    initialValues.put(DOSE_TOTALE, protocollo.getDose_totale());
	    initialValues.put(INTEGRA, fromBooleanToInt(protocollo.getIntegra_paracetamolo()));
	    initialValues.put(GASTRO_NOME, protocollo.getGastro().getNome());
	    initialValues.put(GASTRO_DOSE, protocollo.getGastro().getDosaggio());
	    initialValues.put(PONV_NOME, protocollo.getPonv().getNome());
	    initialValues.put(PONV_POS, protocollo.getPonv().getPosologia());
	    initialValues.put(PONV_DOSE, protocollo.getPonv().getDosaggio());
	    
	    return this.mDb.insert(DATABASE_TABLE_PROTOCOLLOC, null, initialValues);
	}

	private ProtocolloC cursorToProtocollo(Cursor cursor)
	{
		ProtocolloC protocollo = new ProtocolloC();
		protocollo.setFarmaco(new FarmacoDos(cursor.getString(2), cursor.getString(3)));
		protocollo.setAltro_farmaco(new FarmacoDos(cursor.getString(4), cursor.getString(5)));
		protocollo.setSol_fisiologica(cursor.getString(6));
		protocollo.setDose_totale(cursor.getString(7));
		protocollo.setRescue(new Rescue(cursor.getString(8), cursor.getString(9)));
		protocollo.setInfusione_continua(cursor.getString(10));
		protocollo.setDose_bolo(cursor.getString(11));
		protocollo.setTempo_blocco(cursor.getString(12));
		protocollo.setLimite_ore(cursor.getString(13));
		protocollo.setDose_totale(cursor.getString(14));
		protocollo.setIntegra_paracetamolo(fromIntegerToBoolean(cursor.getInt(15)));
		protocollo.setGastro(new Gastroprotezione(cursor.getString(16), cursor.getString(17)));
		protocollo.setPonv(new Ponv(cursor.getString(18), cursor.getString(19), cursor.getString(20)));
		return protocollo;
	}
	
	private int fromBooleanToInt(boolean boolvalue)
	{
		int flag = (boolvalue)? 1 : 0;
		return flag;
	}
	
	private boolean fromIntegerToBoolean(int integervalue)
	{
		boolean flag = (integervalue == 1)? true : false;
		return flag;
	}
}
