package prova.med.db;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import prova.med.obj.AbstractProtocollo;
import prova.med.obj.Elastomero;
import prova.med.obj.FarmacoDos;
import prova.med.obj.Gastroprotezione;
import prova.med.obj.Paziente;
import prova.med.obj.Ponv;
import prova.med.obj.ProtocolloD;
import prova.med.obj.Rescue;

public class ProtocolloDDBAdapter extends PazientiDBAdapter implements
		IProtocolloDBAdapter {

	public static final String ROW_ID_TABLE_PROTOCOLLOD = "_id";	//0
	//CODBARRE	//1
	public static final String FARMACO1_NOME = "farmaco1nome"; //2
	public static final String FARMACO1_DOSE = "farmaco1dose";	//3
	public static final String FARMACO2_NOME = "farmaco2nome";	//4
	public static final String FARMACO2_DOSE = "farmaco2dose";	//5
	public static final String RESCUE_NOME = "rescuenome";	//6
	public static final String RESCUE_POS = "rescuepos";	//7
	public static final String ELASTOMERO_VOL = "elastromerovol";	//8
	public static final String ELASTOMERO_VEL = "elastromerovel";	//9
	public static final String INTEGRA = "integraparacetamolo";		//10
	public static final String GASTRO_NOME = "gastronome";
	public static final String GASTRO_DOSE = "gastrodose";
	public static final String PONV_NOME = "ponvnome";
	public static final String PONV_POS = "ponvpos";
	public static final String PONV_DOSE = "ponvdose";	//15
	
	public static final String DATABASE_TABLE_PROTOCOLLOD = "protocollod";
	
	public ProtocolloDDBAdapter(Context ctx) {
		super(ctx);
		// TODO Auto-generated constructor stub
	}

	@Override
	public boolean createPazienteAndProtocollo(Paziente paz, AbstractProtocollo prot) {
		boolean success = false;
		mDb.beginTransaction();
        try {
        	long inserimentopaziente = createPaziente(paz);
        	long inserimentoprotocollo = createProtocollo((ProtocolloD) prot, paz.getCodice_a_barre());
        	
        	if(inserimentopaziente != -1 && inserimentoprotocollo != -1)
        	{
        		mDb.setTransactionSuccessful();
        		success = true;
        	}
        }catch (Exception e)
        {
        	success = false;
            //Error in between database transaction 
        }finally {
        	mDb.endTransaction();

        }
		return success;
	}

	@Override
	public AbstractProtocollo getProtocollo(String codice_a_barre) {

		ProtocolloD protocollo = null;
		Cursor mCursor =    this.mDb.query(true, DATABASE_TABLE_PROTOCOLLOD, null, CODBARRE + " = ?" ,new String[]{ codice_a_barre}, null, null, null, null);
		
		if(mCursor.moveToFirst())
		{
			protocollo = cursorToProtocollo(mCursor);
		}
		mCursor.close();
		return protocollo;
	}

	@Override
	public boolean updateProtocollo(AbstractProtocollo protocollo, String codice_a_barre) {
		ProtocolloD p = (ProtocolloD) protocollo;
		ContentValues args = new ContentValues();
		
		args.put(CODBARRE, codice_a_barre);
		args.put(FARMACO1_NOME, p.getFarmaco_non_oppiaceo().getNome());
		args.put(FARMACO1_DOSE, p.getFarmaco_non_oppiaceo().getDosaggio());
		args.put(FARMACO2_NOME, p.getFarmaco_oppiaceo().getNome());
		args.put(FARMACO2_DOSE, p.getFarmaco_oppiaceo().getDosaggio());
		args.put(RESCUE_NOME, p.getRescue().getNome());
		args.put(RESCUE_POS, p.getRescue().getPosologia());
		args.put(ELASTOMERO_VOL, p.getElastomero().getVolume());
		args.put(ELASTOMERO_VEL, p.getElastomero().getVelocita());
		args.put(INTEGRA, fromBooleanToInt(p.getIntegra_paracetamolo()));
		args.put(GASTRO_NOME, p.getGastro().getNome());
		args.put(GASTRO_DOSE, p.getGastro().getDosaggio());
		args.put(PONV_NOME, p.getPonv().getNome());
		args.put(PONV_POS, p.getPonv().getPosologia());
		args.put(PONV_DOSE, p.getPonv().getDosaggio());

		return this.mDb.update(DATABASE_TABLE_PROTOCOLLOD, args, CODBARRE + " =?" ,new String[]{codice_a_barre}) >0;

	}

	private long createProtocollo(ProtocolloD protocollo, String codice_a_barre) {
		
	    ContentValues initialValues = new ContentValues();
	    initialValues.put(CODBARRE, codice_a_barre);
	    initialValues.put(FARMACO1_NOME, protocollo.getFarmaco_non_oppiaceo().getNome());
	    initialValues.put(FARMACO1_DOSE, protocollo.getFarmaco_non_oppiaceo().getDosaggio());
	    initialValues.put(FARMACO2_NOME, protocollo.getFarmaco_oppiaceo().getNome());
	    initialValues.put(FARMACO2_DOSE, protocollo.getFarmaco_oppiaceo().getDosaggio());
	    initialValues.put(RESCUE_NOME, protocollo.getRescue().getNome());
	    initialValues.put(RESCUE_POS, protocollo.getRescue().getPosologia());
	    initialValues.put(ELASTOMERO_VOL, protocollo.getElastomero().getVolume());
	    initialValues.put(ELASTOMERO_VEL, protocollo.getElastomero().getVelocita());
	    initialValues.put(INTEGRA, fromBooleanToInt(protocollo.getIntegra_paracetamolo()));
	    initialValues.put(GASTRO_NOME, protocollo.getGastro().getNome());
	    initialValues.put(GASTRO_DOSE, protocollo.getGastro().getDosaggio());
	    initialValues.put(PONV_NOME, protocollo.getPonv().getNome());
	    initialValues.put(PONV_POS, protocollo.getPonv().getPosologia());
	    initialValues.put(PONV_DOSE, protocollo.getPonv().getDosaggio());
	    
	    
	    return this.mDb.insert(DATABASE_TABLE_PROTOCOLLOD, null, initialValues);
	}
	private ProtocolloD cursorToProtocollo(Cursor cursor)
	{
		ProtocolloD protocollo = new ProtocolloD();
		protocollo.setFarmaco_non_oppiaceo(new FarmacoDos(cursor.getString(2), cursor.getString(3)));
		protocollo.setFarmaco_oppiaceo(new FarmacoDos(cursor.getString(4), cursor.getString(5)));
		protocollo.setRescue(new Rescue(cursor.getString(6), cursor.getString(7)));
		protocollo.setElastomero(new Elastomero(cursor.getString(8), cursor.getString(9)));
		protocollo.setIntegra_paracetamolo(fromIntegerToBoolean(cursor.getInt(10)));
		protocollo.setGastro(new Gastroprotezione(cursor.getString(11), cursor.getString(12)));
		protocollo.setPonv(new Ponv(cursor.getString(13), cursor.getString(14), cursor.getString(15)));
		return protocollo;
	}
	
	private int fromBooleanToInt(boolean boolvalue)
	{
		int flag = (boolvalue)? 1 : 0;
		return flag;
	}
	
	private boolean fromIntegerToBoolean(int integervalue)
	{
		boolean flag = (integervalue == 1)? true : false;
		return flag;
	}
}
