package prova.med.db;

import java.util.ArrayList;
import java.util.List;

import prova.med.obj.Rilevazione;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class RilevazioneDBAdapter {

	public static final String ROW_ID_TABLE_RILEVAZIONI = "_id";	//0	  	
	public static final String CODBARRE = "codbarre"; //2
	public static final String DATA = "data"; //2
	public static final String ORA = "ora";	//3
	public static final String SVS_RIP = "svsriposo";	//4
	public static final String SVS_SFO = "svssforzo";	//5
	public static final String VAS_RIP = "vasriposo";	//6
	public static final String VAS_SFO = "vassforzo";	//7
	public static final String SEDE = "sede";	//8
	public static final String SEDAZIONE = "sedazione";	//9
	public static final String FR = "fr";		//10
	public static final String SO2 = "so2";	//11
	public static final String PA = "pa";		//12
	public static final String FC = "fc";	//13
	public static final String EFFETTI_AVVERSI = "effettiavversi";	//14
	public static final String NOTE = "note";		//15

	public static final String DATABASE_TABLE_RILEVAZIONI = "rilevazioni";
	public static final String DATABASE_TABLE_RILEVAZIONI_MASTERCOPY = "rilevazionimastercopy";
	protected DatabaseHelper mDbHelper;
	protected SQLiteDatabase mDb;
	protected final Context mCtx;

	protected static class DatabaseHelper extends SQLiteOpenHelper {

		DatabaseHelper(Context context) {
			super(context, DBAdapter.DATABASE_NAME, null, DBAdapter.DATABASE_VERSION);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		}
	}

	public RilevazioneDBAdapter(Context ctx) {
		this.mCtx = ctx;
	}

	/**
	 * Open the pazienti database. If it cannot be opened, try to create a new
	 * instance of the database. If it cannot be created, throw an exception to
	 * signal the failure
	 * 
	 * @return this (self reference, allowing this to be chained in an
	 *         initialization call)
	 * @throws SQLException
	 *             if the database could be neither opened or created
	 */
	public RilevazioneDBAdapter open() throws SQLException {
		this.mDbHelper = new DatabaseHelper(this.mCtx);
		this.mDb = this.mDbHelper.getWritableDatabase();
		return this;
	}

	/**
	 * close return type: void
	 */
	public void close() {
		this.mDbHelper.close();
	}

	public long createRilevazione(Rilevazione rilevazione, String codice_a_barre)
	{
		ContentValues initialValues = new ContentValues();
		initialValues.put(CODBARRE, codice_a_barre);
		initialValues.put(DATA, rilevazione.getData());
		initialValues.put(ORA, rilevazione.getOra());
		initialValues.put(SVS_RIP, rilevazione.getSvs_riposo());
		initialValues.put(SVS_SFO, rilevazione.getSvs_sforzo());
		initialValues.put(VAS_RIP, rilevazione.getVas_riposo());
		initialValues.put(VAS_SFO, rilevazione.getVas_sforzo());
		initialValues.put(SEDE, rilevazione.getSede());
		initialValues.put(SEDAZIONE, rilevazione.getSedazione());
		initialValues.put(FR, rilevazione.getFr());
		initialValues.put(SO2, rilevazione.getSo2());
		initialValues.put(PA, rilevazione.getPa());
		initialValues.put(FC, rilevazione.getFc());
		initialValues.put(EFFETTI_AVVERSI, rilevazione.getEffetti_avversi());
		initialValues.put(NOTE, rilevazione.getNote());
		return this.mDb.insertWithOnConflict(DATABASE_TABLE_RILEVAZIONI, null, initialValues, SQLiteDatabase.CONFLICT_REPLACE);
	}

	/**
	 * @param codice_a_barre del paziente
	 * @return una list di Rilevazioni (lista vuota se nessuna rilevazione presente)
	 */
	public List<Rilevazione> getRilevazioni(String codice_a_barre) {
		List<Rilevazione> rilevazioni = new ArrayList<Rilevazione>();
		Cursor mCursor =    this.mDb.query(true, DATABASE_TABLE_RILEVAZIONI, null, CODBARRE + "=?" ,new String[]{ codice_a_barre}, null, null, null, null);
		if(mCursor.moveToFirst()){
			while (!mCursor.isAfterLast()) {
				Rilevazione r = cursorToRilevazione(mCursor);
				rilevazioni.add(r);
				mCursor.moveToNext();
			}
		}
		// make sure to close the cursor
		mCursor.close();
		return rilevazioni;
	}

	private Rilevazione cursorToRilevazione(Cursor cursor)
	{
		Rilevazione r = new Rilevazione(cursor.getString(2), cursor.getString(3));
		r.setSvs_riposo(cursor.getInt(4));
		r.setSvs_sforzo(cursor.getInt(5));
		r.setVas_riposo(cursor.getInt(6));
		r.setVas_sforzo(cursor.getInt(7));
		r.setSede(cursor.getInt(8));
		r.setSedazione(cursor.getInt(9));
		r.setFr(cursor.getInt(10));
		r.setSo2(cursor.getInt(11));
		r.setPa(cursor.getInt(12));
		r.setFc(cursor.getInt(13));
		r.setEffetti_avversi(cursor.getString(14));
		r.setNote(cursor.getString(15));
		return r;
	}
}
