package prova.med.db;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Map.Entry;

import prova.med.obj.AbstractProtocollo;
import prova.med.obj.Elastomero;
import prova.med.obj.FarmacoDos;
import prova.med.obj.FarmacoPos;
import prova.med.obj.Gastroprotezione;
import prova.med.obj.Ponv;
import prova.med.obj.ProtocolloA;
import prova.med.obj.ProtocolloB;
import prova.med.obj.ProtocolloC;
import prova.med.obj.ProtocolloD;
import prova.med.obj.Rescue;
import prova.med.obj.Rilevazione;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;

public class SyncDBAdapter {

	public static final String SUCCESS = "Sincronizzazione riuscita";
	public static final String ERROR = "Operazione fallita";
	protected DatabaseHelper mDbHelper;
	protected SQLiteDatabase mDb;
	protected final Context mCtx;

	protected static class DatabaseHelper extends SQLiteOpenHelper {


		DatabaseHelper(Context context) {
			super(context, DBAdapter.DATABASE_NAME, null, DBAdapter.DATABASE_VERSION);
		}

		@Override
		public void onCreate(SQLiteDatabase db) {
		}

		@Override
		public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
		}
	}

	public SyncDBAdapter(Context ctx) {
		this.mCtx = ctx;
	}

	public JsonArray getPazientiDBTableAsJsonArray()
	{
		Cursor mCursor = getAllRowsFromTable(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI);

		//fare un altro array 
		JsonArray jsonarray = getJsonArrayFromCursorPazienti(mCursor);
		return jsonarray;

	}

	public HashMap<String, HashMap<String, AbstractProtocollo>> getProtocolliAsHashMap()
	{
		HashMap<String, HashMap<String, AbstractProtocollo>> tables = new HashMap<String, HashMap<String,AbstractProtocollo>>();
		Cursor cursor_A = getAllRowsFromTable(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA);
		tables.put(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA, getHashMapAfromCursor(cursor_A));
		Cursor cursor_B = getAllRowsFromTable(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB);
		tables.put(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB, getHashMapBfromCursor(cursor_B));
		Cursor cursor_C = getAllRowsFromTable(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC);
		tables.put(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC, getHashMapCfromCursor(cursor_C));
		Cursor cursor_D = getAllRowsFromTable(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD);
		tables.put(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD, getHashMapDfromCursor(cursor_D));
		return tables;
	}

	private HashMap<String, AbstractProtocollo> getHashMapAfromCursor(Cursor cursor_A) {

		HashMap<String, AbstractProtocollo> map = new HashMap<String, AbstractProtocollo>();
		if(cursor_A.moveToFirst())
		{
			do
			{
				ProtocolloA protocollo = new ProtocolloA();
				protocollo.setFarmacopos1(new FarmacoPos(cursor_A.getString(2), cursor_A.getString(3)));
				protocollo.setFarmacopos2(new FarmacoPos(cursor_A.getString(4), cursor_A.getString(5)));
				protocollo.setRescue(new Rescue(cursor_A.getString(6), cursor_A.getString(7)));
				protocollo.setGastro(new Gastroprotezione(cursor_A.getString(8), cursor_A.getString(9)));
				protocollo.setPonv(new Ponv(cursor_A.getString(10), cursor_A.getString(11), cursor_A.getString(12)));
				map.put(cursor_A.getString(1), protocollo);
			}
			while(cursor_A.moveToNext());
		}
		return map;
	}

	private HashMap<String, AbstractProtocollo> getHashMapBfromCursor(Cursor cursor_B) {
		HashMap<String, AbstractProtocollo> map = new HashMap<String, AbstractProtocollo>();
		if(cursor_B.moveToFirst())
		{
			do
			{
				ProtocolloB protocollo = new ProtocolloB();
				protocollo.setFarmaco1(new FarmacoDos(cursor_B.getString(2), cursor_B.getString(3)));
				protocollo.setFarmaco2(new FarmacoDos(cursor_B.getString(4), cursor_B.getString(5)));
				protocollo.setAltro_farmaco(new FarmacoDos(cursor_B.getString(6), cursor_B.getString(7)));
				protocollo.setRescue(new Rescue(cursor_B.getString(8), cursor_B.getString(9)));
				protocollo.setElastomero(new Elastomero(cursor_B.getString(10), cursor_B.getString(11)));
				protocollo.setIntegra_paracetamolo(fromIntegerToBoolean(cursor_B.getInt(12)));
				protocollo.setGastro(new Gastroprotezione(cursor_B.getString(13), cursor_B.getString(14)));
				protocollo.setPonv(new Ponv(cursor_B.getString(15), cursor_B.getString(16), cursor_B.getString(17)));
				map.put(cursor_B.getString(1), protocollo);
			}
			while(cursor_B.moveToNext());
		}
		return map;
	}

	private HashMap<String, AbstractProtocollo> getHashMapCfromCursor(Cursor cursor_C) {
		HashMap<String, AbstractProtocollo> map = new HashMap<String, AbstractProtocollo>();
		if(cursor_C.moveToFirst())
		{
			do
			{
				ProtocolloC protocollo = new ProtocolloC();
				protocollo.setFarmaco(new FarmacoDos(cursor_C.getString(2), cursor_C.getString(3)));
				protocollo.setAltro_farmaco(new FarmacoDos(cursor_C.getString(4), cursor_C.getString(5)));
				protocollo.setSol_fisiologica(cursor_C.getString(6));
				protocollo.setDose_totale(cursor_C.getString(7));
				protocollo.setRescue(new Rescue(cursor_C.getString(8), cursor_C.getString(9)));
				protocollo.setInfusione_continua(cursor_C.getString(10));
				protocollo.setDose_bolo(cursor_C.getString(11));
				protocollo.setTempo_blocco(cursor_C.getString(12));
				protocollo.setLimite_ore(cursor_C.getString(13));
				protocollo.setDose_totale(cursor_C.getString(14));
				protocollo.setIntegra_paracetamolo(fromIntegerToBoolean(cursor_C.getInt(15)));
				protocollo.setGastro(new Gastroprotezione(cursor_C.getString(16), cursor_C.getString(17)));
				protocollo.setPonv(new Ponv(cursor_C.getString(18), cursor_C.getString(19), cursor_C.getString(20)));
				map.put(cursor_C.getString(1), protocollo);
			}
			while(cursor_C.moveToNext());
		}
		return map;
	}

	private HashMap<String, AbstractProtocollo> getHashMapDfromCursor(Cursor cursor_D) {
		HashMap<String, AbstractProtocollo> map = new HashMap<String, AbstractProtocollo>();
		if(cursor_D.moveToFirst())
		{
			do
			{
				ProtocolloD protocollo = new ProtocolloD();
				protocollo.setFarmaco_non_oppiaceo(new FarmacoDos(cursor_D.getString(2), cursor_D.getString(3)));
				protocollo.setFarmaco_oppiaceo(new FarmacoDos(cursor_D.getString(4), cursor_D.getString(5)));
				protocollo.setRescue(new Rescue(cursor_D.getString(6), cursor_D.getString(7)));
				protocollo.setElastomero(new Elastomero(cursor_D.getString(8), cursor_D.getString(9)));
				protocollo.setIntegra_paracetamolo(fromIntegerToBoolean(cursor_D.getInt(10)));
				protocollo.setGastro(new Gastroprotezione(cursor_D.getString(11), cursor_D.getString(12)));
				protocollo.setPonv(new Ponv(cursor_D.getString(13), cursor_D.getString(14), cursor_D.getString(15)));
				map.put(cursor_D.getString(1), protocollo);
			}
			while(cursor_D.moveToNext());
		}
		return map;
	}
	public HashMap<String, ArrayList<Rilevazione>> getRilevazioniDBTableAsHashMap()
	{
		HashMap<String,ArrayList<Rilevazione>> map = new HashMap<String, ArrayList<Rilevazione>>();
		//ottengo tutti i codici a barre
		Cursor codCursor = this.mDb.query(true, RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI, new String[]{RilevazioneDBAdapter.CODBARRE}, null, null,null,null,null,null);

		if (codCursor.moveToFirst())
		{
			//per ogni codice a barre, ottengo le relative rilevazioni
			do {     

				String codice_a_barre = codCursor.getString(codCursor.getColumnIndex(RilevazioneDBAdapter.CODBARRE));
				ArrayList<Rilevazione> rilevazioni = new ArrayList<Rilevazione>();
				Cursor rilCursor = this.mDb.query(true, RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI, null, RilevazioneDBAdapter.CODBARRE + "=?" ,new String[]{ codice_a_barre}, null, null, null, null);

				if(rilCursor.moveToFirst())
				{
					do{
						Rilevazione r = new Rilevazione(rilCursor.getString(2), rilCursor.getString(3));
						r.setSvs_riposo(rilCursor.getInt(4));
						r.setSvs_sforzo(rilCursor.getInt(5));
						r.setVas_riposo(rilCursor.getInt(6));
						r.setVas_sforzo(rilCursor.getInt(7));
						r.setSede(rilCursor.getInt(8));
						r.setSedazione(rilCursor.getInt(9));
						r.setFr(rilCursor.getInt(10));
						r.setSo2(rilCursor.getInt(11));
						r.setPa(rilCursor.getInt(12));
						r.setFc(rilCursor.getInt(13));
						r.setEffetti_avversi(rilCursor.getString(14));
						r.setNote(rilCursor.getString(15));
						rilevazioni.add(r);
					} while (rilCursor.moveToNext());
				}

				map.put(codice_a_barre, rilevazioni);
			} while (codCursor.moveToNext());
		}
		return map;
	}

	public ArrayList<String> getPazientiCancellatiAsArrayList()
	{
		Cursor cursor = getAllRowsFromTable(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI);
		ArrayList<String> pazienti_cancellati = new ArrayList<String>();
		if (cursor.moveToFirst())
		{
			do {          
				pazienti_cancellati.add(cursor.getString(1));
			} while (cursor.moveToNext());
		}
		return pazienti_cancellati;
	}

	public void deleteAllRowsFromTable(String table_name)
	{
		this.mDb.delete(table_name, null, null);
	}

	private Cursor getAllRowsFromTable(String table_name)
	{
		return this.mDb.query(true, table_name, null, null, null, null, null, null, null);
	}

	private JsonArray getJsonArrayFromCursorPazienti(Cursor cursor)
	{
		JsonArray jsonarray = new JsonArray();
		if (cursor.moveToFirst())
		{
			do {          
				JsonObject jsonobj = new JsonObject();
				jsonobj.addProperty(PazientiDBAdapter.NOME, cursor.getString(1));
				jsonobj.addProperty(PazientiDBAdapter.COGNOME, cursor.getString(2));
				jsonobj.addProperty(PazientiDBAdapter.INGRESSO, cursor.getString(3));
				jsonobj.addProperty(PazientiDBAdapter.NLETTO, cursor.getString(4));
				jsonobj.addProperty(PazientiDBAdapter.REPARTO, cursor.getString(5));
				jsonobj.addProperty(PazientiDBAdapter.PIANO, cursor.getString(6));
				jsonobj.addProperty(PazientiDBAdapter.CODINTERVENTO, cursor.getString(7));
				jsonobj.addProperty(PazientiDBAdapter.CODDIAGNOSI, cursor.getString(8));
				jsonobj.addProperty(PazientiDBAdapter.PATOLOGIA, cursor.getString(9));
				jsonobj.addProperty(PazientiDBAdapter.ALLERGIE, cursor.getString(10));
				jsonobj.addProperty(PazientiDBAdapter.ALLERGIEALTRO, cursor.getString(11));
				jsonobj.addProperty(PazientiDBAdapter.CODBARRE, cursor.getString(12));
				jsonobj.addProperty(PazientiDBAdapter.CREATININA, cursor.getString(13));
				jsonobj.addProperty(PazientiDBAdapter.ALT, cursor.getString(14));
				jsonobj.addProperty(PazientiDBAdapter.AST, cursor.getString(15));
				jsonobj.addProperty(PazientiDBAdapter.ANNI, cursor.getString(16));
				jsonobj.addProperty(PazientiDBAdapter.PROTOCOLLO, cursor.getString(17));
				jsonobj.addProperty(PazientiDBAdapter.ULTIMA_MODIFICA, cursor.getString(18));
				jsonarray.add(jsonobj);
			} while (cursor.moveToNext());
		}

		return jsonarray;
	}

	protected long insertPaziente(JsonObject jsonobject_paziente)
	{
		ContentValues initialValues = new ContentValues();
		for (Entry<String, JsonElement> iterable_element : jsonobject_paziente.entrySet())
		{

			initialValues.put(iterable_element.getKey(), iterable_element.getValue().getAsString());
		}
		return this.mDb.insert(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI, null, initialValues);
	}

	protected long insertProtocolloA(ProtocolloA protocollo, String codice_a_barre)
	{
		ContentValues initialValues = new ContentValues();
		initialValues.put(ProtocolloADBAdapter.CODBARRE, codice_a_barre);
		initialValues.put(ProtocolloADBAdapter.FARMACO1_NOME, protocollo.getFarmacopos1().getNome());
		initialValues.put(ProtocolloADBAdapter.FARMACO1_POS, protocollo.getFarmacopos1().getPosologia());
		initialValues.put(ProtocolloADBAdapter.FARMACO2_NOME, protocollo.getFarmacopos2().getNome());
		initialValues.put(ProtocolloADBAdapter.FARMACO2_POS, protocollo.getFarmacopos2().getPosologia());
		initialValues.put(ProtocolloADBAdapter.RESCUE_NOME, protocollo.getRescue().getNome());
		initialValues.put(ProtocolloADBAdapter.RESCUE_POS, protocollo.getRescue().getPosologia());
		initialValues.put(ProtocolloADBAdapter.GASTRO_NOME, protocollo.getGastro().getNome());
		initialValues.put(ProtocolloADBAdapter.GASTRO_DOSE, protocollo.getGastro().getDosaggio());
		initialValues.put(ProtocolloADBAdapter.PONV_NOME, protocollo.getPonv().getNome());
		initialValues.put(ProtocolloADBAdapter.PONV_POS, protocollo.getPonv().getPosologia());
		initialValues.put(ProtocolloADBAdapter.PONV_DOSE, protocollo.getPonv().getDosaggio());

		return this.mDb.insertWithOnConflict(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
	}

	protected long insertProtocolloB(ProtocolloB protocollo, String codice_a_barre)
	{
		ContentValues initialValues = new ContentValues();
		initialValues.put(ProtocolloBDBAdapter.CODBARRE, codice_a_barre);
		initialValues.put(ProtocolloBDBAdapter.FARMACO1_NOME, protocollo.getFarmaco1().getNome());
		initialValues.put(ProtocolloBDBAdapter.FARMACO1_DOSE, protocollo.getFarmaco1().getDosaggio());
		initialValues.put(ProtocolloBDBAdapter.FARMACO2_NOME, protocollo.getFarmaco2().getNome());
		initialValues.put(ProtocolloBDBAdapter.FARMACO2_DOSE, protocollo.getFarmaco2().getDosaggio());
		initialValues.put(ProtocolloBDBAdapter.ALTROFARMACO_NOME, protocollo.getAltro_farmaco().getNome());
		initialValues.put(ProtocolloBDBAdapter.ALTROFARMACO_DOSE, protocollo.getAltro_farmaco().getDosaggio());
		initialValues.put(ProtocolloBDBAdapter.RESCUE_NOME, protocollo.getRescue().getNome());
		initialValues.put(ProtocolloBDBAdapter.RESCUE_POS, protocollo.getRescue().getPosologia());
		initialValues.put(ProtocolloBDBAdapter.ELASTOMERO_VOL, protocollo.getElastomero().getVolume());
		initialValues.put(ProtocolloBDBAdapter.ELASTOMERO_VEL, protocollo.getElastomero().getVelocita());
		initialValues.put(ProtocolloBDBAdapter.INTEGRA, fromBooleanToInt(protocollo.getIntegra_paracetamolo()));
		initialValues.put(ProtocolloBDBAdapter.GASTRO_NOME, protocollo.getGastro().getNome());
		initialValues.put(ProtocolloBDBAdapter.GASTRO_DOSE, protocollo.getGastro().getDosaggio());
		initialValues.put(ProtocolloBDBAdapter.PONV_NOME, protocollo.getPonv().getNome());
		initialValues.put(ProtocolloBDBAdapter.PONV_POS, protocollo.getPonv().getPosologia());
		initialValues.put(ProtocolloBDBAdapter.PONV_DOSE, protocollo.getPonv().getDosaggio());

		return this.mDb.insertWithOnConflict(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
	}

	protected long insertProtocolloC(ProtocolloC protocollo, String codice_a_barre)
	{
		ContentValues initialValues = new ContentValues();
		initialValues.put(ProtocolloCDBAdapter.CODBARRE, codice_a_barre);
		initialValues.put(ProtocolloCDBAdapter.FARMACO1_NOME, protocollo.getFarmaco().getNome());
		initialValues.put(ProtocolloCDBAdapter.FARMACO1_DOSE, protocollo.getFarmaco().getDosaggio());
		initialValues.put(ProtocolloCDBAdapter.FARMACO2_NOME, protocollo.getAltro_farmaco().getNome());
		initialValues.put(ProtocolloCDBAdapter.FARMACO2_DOSE, protocollo.getAltro_farmaco().getDosaggio());
		initialValues.put(ProtocolloCDBAdapter.SOL_FISIOLOGICA, protocollo.getSol_fisiologica());
		initialValues.put(ProtocolloCDBAdapter.VOLUME_TOTALE, protocollo.getVolume_totale());
		initialValues.put(ProtocolloCDBAdapter.RESCUE_NOME, protocollo.getRescue().getNome());
		initialValues.put(ProtocolloCDBAdapter.RESCUE_POS, protocollo.getRescue().getPosologia());
		initialValues.put(ProtocolloCDBAdapter.INFUSIONE_CONTINUA, protocollo.getInfusione_continua());
		initialValues.put(ProtocolloCDBAdapter.DOSE_BOLO, protocollo.getDose_bolo());
		initialValues.put(ProtocolloCDBAdapter.TEMPO_BLOCCO, protocollo.getTempo_blocco());
		initialValues.put(ProtocolloCDBAdapter.TEMPO_LIMITE, protocollo.getLimite_ore());
		initialValues.put(ProtocolloCDBAdapter.DOSE_TOTALE, protocollo.getDose_totale());
		initialValues.put(ProtocolloCDBAdapter.INTEGRA, fromBooleanToInt(protocollo.getIntegra_paracetamolo()));
		initialValues.put(ProtocolloCDBAdapter.GASTRO_NOME, protocollo.getGastro().getNome());
		initialValues.put(ProtocolloCDBAdapter.GASTRO_DOSE, protocollo.getGastro().getDosaggio());
		initialValues.put(ProtocolloCDBAdapter.PONV_NOME, protocollo.getPonv().getNome());
		initialValues.put(ProtocolloCDBAdapter.PONV_POS, protocollo.getPonv().getPosologia());
		initialValues.put(ProtocolloCDBAdapter.PONV_DOSE, protocollo.getPonv().getDosaggio());

		return this.mDb.insertWithOnConflict(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
	}

	protected long insertProtocolloD(ProtocolloD protocollo, String codice_a_barre) {

		ContentValues initialValues = new ContentValues();
		initialValues.put(ProtocolloDDBAdapter.CODBARRE, codice_a_barre);
		initialValues.put(ProtocolloDDBAdapter.FARMACO1_NOME, protocollo.getFarmaco_non_oppiaceo().getNome());
		initialValues.put(ProtocolloDDBAdapter.FARMACO1_DOSE, protocollo.getFarmaco_non_oppiaceo().getDosaggio());
		initialValues.put(ProtocolloDDBAdapter.FARMACO2_NOME, protocollo.getFarmaco_oppiaceo().getNome());
		initialValues.put(ProtocolloDDBAdapter.FARMACO2_DOSE, protocollo.getFarmaco_oppiaceo().getDosaggio());
		initialValues.put(ProtocolloDDBAdapter.RESCUE_NOME, protocollo.getRescue().getNome());
		initialValues.put(ProtocolloDDBAdapter.RESCUE_POS, protocollo.getRescue().getPosologia());
		initialValues.put(ProtocolloDDBAdapter.ELASTOMERO_VOL, protocollo.getElastomero().getVolume());
		initialValues.put(ProtocolloDDBAdapter.ELASTOMERO_VEL, protocollo.getElastomero().getVelocita());
		initialValues.put(ProtocolloDDBAdapter.INTEGRA, fromBooleanToInt(protocollo.getIntegra_paracetamolo()));
		initialValues.put(ProtocolloDDBAdapter.GASTRO_NOME, protocollo.getGastro().getNome());
		initialValues.put(ProtocolloDDBAdapter.GASTRO_DOSE, protocollo.getGastro().getDosaggio());
		initialValues.put(ProtocolloDDBAdapter.PONV_NOME, protocollo.getPonv().getNome());
		initialValues.put(ProtocolloDDBAdapter.PONV_POS, protocollo.getPonv().getPosologia());
		initialValues.put(ProtocolloDDBAdapter.PONV_DOSE, protocollo.getPonv().getDosaggio());


		return this.mDb.insertWithOnConflict(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
	}
	protected long insertRilevazione(Rilevazione rilevazione, String codice_a_barre)
	{
		ContentValues initialValues = new ContentValues();
		initialValues.put(RilevazioneDBAdapter.CODBARRE, codice_a_barre);
		initialValues.put(RilevazioneDBAdapter.DATA, rilevazione.getData());
		initialValues.put(RilevazioneDBAdapter.ORA, rilevazione.getOra());
		initialValues.put(RilevazioneDBAdapter.SVS_RIP, rilevazione.getSvs_riposo());
		initialValues.put(RilevazioneDBAdapter.SVS_SFO, rilevazione.getSvs_sforzo());
		initialValues.put(RilevazioneDBAdapter.VAS_RIP, rilevazione.getVas_riposo());
		initialValues.put(RilevazioneDBAdapter.VAS_SFO, rilevazione.getVas_sforzo());
		initialValues.put(RilevazioneDBAdapter.SEDE, rilevazione.getSede());
		initialValues.put(RilevazioneDBAdapter.SEDAZIONE, rilevazione.getSedazione());
		initialValues.put(RilevazioneDBAdapter.FR, rilevazione.getFr());
		initialValues.put(RilevazioneDBAdapter.SO2, rilevazione.getSo2());
		initialValues.put(RilevazioneDBAdapter.PA, rilevazione.getPa());
		initialValues.put(RilevazioneDBAdapter.FC, rilevazione.getFc());
		initialValues.put(RilevazioneDBAdapter.EFFETTI_AVVERSI, rilevazione.getEffetti_avversi());
		initialValues.put(RilevazioneDBAdapter.NOTE, rilevazione.getNote());
		return this.mDb.insertWithOnConflict(RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI, null, initialValues, SQLiteDatabase.CONFLICT_REPLACE);
	}

	private boolean fromIntegerToBoolean(int integervalue)
	{
		boolean flag = (integervalue == 1)? true : false;
		return flag;
	}

	private int fromBooleanToInt(boolean boolvalue)
	{
		int flag = (boolvalue)? 1 : 0;
		return flag;
	}

	public SyncDBAdapter open() throws SQLException {
		this.mDbHelper = new DatabaseHelper(this.mCtx);
		this.mDb = this.mDbHelper.getWritableDatabase();
		return this;
	}

	public void close() {
		this.mDbHelper.close();
	}
}
