package prova.med.db;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Set;

import prova.med.obj.AbstractProtocollo;
import prova.med.obj.ProtocolloA;
import prova.med.obj.ProtocolloB;
import prova.med.obj.ProtocolloC;
import prova.med.obj.ProtocolloD;
import prova.med.obj.Rilevazione;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;

import android.content.ContentValues;
import android.content.Context;
import android.database.sqlite.SQLiteDatabase;

public class SyncDBAdapterClient extends SyncDBAdapter{

	public SyncDBAdapterClient(Context ctx) {
		super(ctx);
	}

	public String writeSyncedDB(JsonArray pazienti,HashMap<String, HashMap<String, AbstractProtocollo>> protocolli, HashMap<String, ArrayList<Rilevazione>> rilevazioni, ArrayList<String> cancellati)
	{
		String result = "";

		mDb.beginTransaction();
		try {

			//svuoto vecchie tabelle
			deleteAllRowsFromTable(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA);
			deleteAllRowsFromTable(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB);
			deleteAllRowsFromTable(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC);
			deleteAllRowsFromTable(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD);
			deleteAllRowsFromTable(RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI);
			deleteAllRowsFromTable(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI);

			copyPazienti(pazienti);
			copyProtocolli(protocolli);
			copyRilevazioni(rilevazioni);
			copyPazientiCancellati(cancellati);
			mDb.setTransactionSuccessful();

			result = SUCCESS;

		}catch (Exception e)
		{
			result = ERROR;

		}finally {

			//
			mDb.endTransaction();
		}

		return result;
	}

	private void copyPazienti(JsonArray pazienti)
	{
		for (JsonElement jsonElement : pazienti) {
			insertPaziente((JsonObject) jsonElement);
		}
	}

	private void copyProtocolli(HashMap<String, HashMap<String, AbstractProtocollo>> map_protocolli)
	{
		HashMap<String, AbstractProtocollo> prot_A = map_protocolli.get(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA);
		HashMap<String, AbstractProtocollo> prot_B = map_protocolli.get(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB);
		HashMap<String, AbstractProtocollo> prot_C = map_protocolli.get(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC);
		HashMap<String, AbstractProtocollo> prot_D = map_protocolli.get(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD);

		for (String codice_a_barre : prot_A.keySet()) {			
			ProtocolloA protocollo = (ProtocolloA) prot_A.get(codice_a_barre);
			insertProtocolloA(protocollo, codice_a_barre);
		}
		
		for (String codice_a_barre : prot_B.keySet()) {			
			ProtocolloB protocollo = (ProtocolloB) prot_B.get(codice_a_barre);
			insertProtocolloB(protocollo, codice_a_barre);
		}
		
		for (String codice_a_barre : prot_C.keySet()) {			
			ProtocolloC protocollo = (ProtocolloC) prot_C.get(codice_a_barre);
			insertProtocolloC(protocollo, codice_a_barre);
		}
		
		for (String codice_a_barre : prot_D.keySet()) {			
			ProtocolloD protocollo = (ProtocolloD) prot_D.get(codice_a_barre);
			insertProtocolloD(protocollo, codice_a_barre);
		}
		
	}

	private void copyRilevazioni(HashMap<String, ArrayList<Rilevazione>> map_rilevazioni)
	{
		Set<String> keys = map_rilevazioni.keySet();
		for (String codice_a_barre : keys) {
			ArrayList<Rilevazione> list_rilevazioni = map_rilevazioni.get(codice_a_barre);
			for (Rilevazione r : list_rilevazioni) {
				insertRilevazione(r, codice_a_barre);
			}
		}
	}

	private void copyPazientiCancellati(ArrayList<String> cancellati)
	{
		for (String cod_barre : cancellati) {
			ContentValues initialValues = new ContentValues();
			initialValues.put(PazientiDBAdapter.CODBARRE, cod_barre);
			this.mDb.insertWithOnConflict(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
		}
	}
}
