package prova.med.db;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Set;
import java.util.Map.Entry;

import prova.med.obj.AbstractProtocollo;
import prova.med.obj.ProtocolloA;
import prova.med.obj.ProtocolloB;
import prova.med.obj.ProtocolloC;
import prova.med.obj.ProtocolloD;
import prova.med.obj.Rilevazione;

import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;

public class SyncDBAdapterServer extends SyncDBAdapter{

	public SyncDBAdapterServer(Context ctx) {
		super(ctx);
	}

	public String syncDB(JsonArray pazienti,HashMap<String, HashMap<String, AbstractProtocollo>> protocolli, HashMap<String, ArrayList<Rilevazione>> rilevazioni, ArrayList<String> pazienti_cancellati)
	{
		String result = "";


		mDb.beginTransaction();
		try {

			//sync
			syncPazienti(pazienti);
			syncProtocolli(protocolli);
			syncRilevazioni(rilevazioni);
			syncCancellazioni(pazienti_cancellati);

			mDb.setTransactionSuccessful();

			result = SUCCESS;

		}catch (Exception e)
		{
			result = ERROR;

		}finally {

			//
			mDb.endTransaction();
		}

		return result;
	}

	private void syncPazienti(JsonArray pazienti)
	{
		//scorro tutto l'array di pazienti ricevuto
		for (JsonElement jsonElement : pazienti) {
			String codice_a_barre = ((JsonObject)jsonElement).get(PazientiDBAdapter.CODBARRE).getAsString();

			//controllo che il paziente non sia fra quelli cancellati in giornata
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst() )
			{
				Cursor paziente_row = this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null);
				//paziente non presente -> lo aggiungo
				if(!paziente_row.moveToFirst())
					insertPaziente((JsonObject) jsonElement);
				//paziente aggiornato pi recentemente -> lo aggiorno
				else 
					if(paziente_row.getString(18).compareTo(((JsonObject)jsonElement).get(PazientiDBAdapter.ULTIMA_MODIFICA).getAsString()) < 0) 
						updatePaziente((JsonObject) jsonElement, codice_a_barre);

			}
		}
	}

	private void syncRilevazioni(HashMap<String, ArrayList<Rilevazione>> map_rilevazioni)
	{
		Set<String> keys = map_rilevazioni.keySet();
		for (String codice_a_barre : keys) {
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst())
			{
				ArrayList<Rilevazione> list_rilevazioni = map_rilevazioni.get(codice_a_barre);
				for (Rilevazione r : list_rilevazioni) {

					insertRilevazione(r, codice_a_barre);
				}
			}

		}
	}

	private void syncCancellazioni(ArrayList<String> pazienti_cancellati) {
		for (String cod_barre : pazienti_cancellati) {
			this.mDb.delete(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre}) ;
			this.mDb.delete(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre}) ;
			this.mDb.delete(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre});
			this.mDb.delete(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre});
			this.mDb.delete(RilevazioneDBAdapter.DATABASE_TABLE_RILEVAZIONI, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre}) ;
			this.mDb.delete(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI, PazientiDBAdapter.CODBARRE + " =?", new String[]{cod_barre});
			ContentValues initialValues = new ContentValues();
			initialValues.put(PazientiDBAdapter.CODBARRE, cod_barre);
			this.mDb.insertWithOnConflict(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI, null, initialValues, SQLiteDatabase.CONFLICT_IGNORE);
		}

	}
	private void syncProtocolli(HashMap<String, HashMap<String, AbstractProtocollo>> protocolli)
	{
		HashMap<String, AbstractProtocollo> protocolloA_table = protocolli.get(ProtocolloADBAdapter.DATABASE_TABLE_PROTOCOLLOA);
		Set<String> keys = protocolloA_table.keySet();
		for (String codice_a_barre : keys) {
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst())
			{
				ProtocolloA protocollo = (ProtocolloA) protocolloA_table.get(codice_a_barre);
				insertProtocolloA(protocollo, codice_a_barre);
			}
		}

		HashMap<String, AbstractProtocollo> protocolloB_table = protocolli.get(ProtocolloBDBAdapter.DATABASE_TABLE_PROTOCOLLOB);
		keys = protocolloB_table.keySet();
		for (String codice_a_barre : keys) {
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst())
			{
				ProtocolloB protocollo = (ProtocolloB) protocolloB_table.get(codice_a_barre);
				insertProtocolloB(protocollo, codice_a_barre);
			}
		}
		HashMap<String, AbstractProtocollo> protocolloC_table = protocolli.get(ProtocolloCDBAdapter.DATABASE_TABLE_PROTOCOLLOC);
		keys = protocolloC_table.keySet();
		for (String codice_a_barre : keys) {
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst())
			{
				ProtocolloC protocollo = (ProtocolloC) protocolloC_table.get(codice_a_barre);
				insertProtocolloC(protocollo, codice_a_barre);
			}
		}
		HashMap<String, AbstractProtocollo> protocolloD_table = protocolli.get(ProtocolloDDBAdapter.DATABASE_TABLE_PROTOCOLLOD);
		keys = protocolloD_table.keySet();
		for (String codice_a_barre : keys) {
			if(! this.mDb.query(true, PazientiDBAdapter.DATABASE_TABLE_PAZIENTI_CANCELLATI , null, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre}, null, null, null, null).moveToFirst())
			{
				ProtocolloD protocollo = (ProtocolloD) protocolloD_table.get(codice_a_barre);
				insertProtocolloD(protocollo, codice_a_barre);
			}
		}
	}

	private void updatePaziente(JsonObject jsonobject_paziente, String codice_a_barre) {
		ContentValues values = new ContentValues();
		for (Entry<String, JsonElement> iterable_element : jsonobject_paziente.entrySet())
		{

			values.put(iterable_element.getKey(), iterable_element.getValue().getAsString());
		}

		this.mDb.update(PazientiDBAdapter.DATABASE_TABLE_PAZIENTI, values, PazientiDBAdapter.CODBARRE + "=?", new String[] {codice_a_barre});
	}
}
