package prova.med.frag;

import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Locale;

import android.graphics.Color;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.CheckBox;
import android.widget.EditText;
import android.widget.Spinner;
import android.widget.TextView;
import prova.med.boris.R;
import prova.med.db.ProtocolloDDBAdapter;
import prova.med.obj.*;

public class ProtocolloDFrag extends AbstractProtocolloFrag {

	private ProtocolloDDBAdapter datasource;
	private Spinner spinner_velocita;
	private Spinner spinner_volume;
	private Spinner spinner_farmaco1;
	private EditText editText_dos_farmaco1;
	private Spinner spinner_farmaco2;
	private EditText editText_dos_farmaco2;
	private TextView textView_stima;
	private CheckBox checkbox_paracetamolo;
	private TextView textView_paracetamolo;
	private Spinner spinner_rescue;
	private Spinner spinner_posologia_rescue;
	private Spinner spinner_gastro;
	private EditText editText_dos_gastro;
	private Spinner spinner_ponv;
	private Spinner spinner_pos_ponv;
	private EditText editText_dos_ponv;

	@Override
	public View onCreateView(LayoutInflater inflater,
			ViewGroup container, Bundle savedInstanceState) {

		datasource = new ProtocolloDDBAdapter(getActivity().getApplicationContext());
		datasource.open();
		/**
		 * Inflate the layout for this fragment
		 */
		View rootView = inflater.inflate(
				R.layout.tabprotocollod, container, false);

		spinner_farmaco1 = (Spinner)rootView.findViewById(R.id.SpinnerFarmacoD1);
		editText_dos_farmaco1 = (EditText)rootView.findViewById(R.id.EditTextDoseD1);
		spinner_farmaco2 = (Spinner)rootView.findViewById(R.id.SpinnerFarmacoD2);
		editText_dos_farmaco2 = (EditText)rootView.findViewById(R.id.EditTextDoseD2);
		spinner_volume = (Spinner)rootView.findViewById(R.id.spinnerVolumeD);
		spinner_velocita = (Spinner)rootView.findViewById(R.id.spinnerVelocitaD);
		textView_stima = (TextView) rootView.findViewById(R.id.textviewStimaD);
		ElastomeroListener elastomeroListener = new ElastomeroListener();
		spinner_velocita.setOnItemSelectedListener(elastomeroListener);
		spinner_volume.setOnItemSelectedListener(elastomeroListener);

		checkbox_paracetamolo=(CheckBox)rootView.findViewById(R.id.checkBoxIntegraParacetamoloD);
		textView_paracetamolo = (TextView)rootView.findViewById(R.id.TextViewIntegraParacetamoloD);
		checkbox_paracetamolo.setOnClickListener(new OnClickListener() {
			@Override
			public void onClick(View v) {

				if(((CheckBox)v).isChecked())
					textView_paracetamolo.setTextColor(Color.BLACK);
				else
					textView_paracetamolo.setTextColor(Color.GRAY);
			}
		});

		spinner_rescue = (Spinner)rootView.findViewById(R.id.SpinnerRescueD);
		spinner_posologia_rescue = (Spinner)rootView.findViewById(R.id.SpinnerPosologiaRescueD);
		
		spinner_gastro = (Spinner) rootView.findViewById(R.id.SpinnerGastroprotezioneD);
		editText_dos_gastro = (EditText) rootView.findViewById(R.id.EditTextDosaggioGastroD);
		spinner_ponv = (Spinner) rootView.findViewById(R.id.SpinnerPonvD);
		spinner_pos_ponv =  (Spinner)rootView.findViewById(R.id.SpinnerposologiaalinD);
		editText_dos_ponv = (EditText)rootView.findViewById(R.id.EditTextDosaggioPonvD);

		return rootView;

	}

	@Override
	public String checkFields() {
		if( editText_dos_farmaco1.getText().toString().trim().isEmpty() )
			return "Primo farmaco: dosaggio mancante";
		if( (!spinner_farmaco2.getSelectedItem().toString().equals("-")) && editText_dos_farmaco2.getText().toString().trim().isEmpty() )
			return "Secondo farmaco: dosaggio mancante";
		if( (!spinner_gastro.getSelectedItem().toString().equals("-")) && editText_dos_gastro.getText().toString().trim().isEmpty() )
			return "Gastroprotezione: dosaggio mancante";
		if( (!spinner_ponv.getSelectedItem().toString().equals("-")) && editText_dos_ponv.getText().toString().trim().isEmpty() )
			return "Ponv: dosaggio mancante";
		return SUCCESS;
	}

	@Override
	public AbstractProtocollo createProtocol()
	{
		ProtocolloD p = new ProtocolloD();
		p.setFarmaco_non_oppiaceo(new FarmacoDos( spinner_farmaco1.getSelectedItem().toString(), editText_dos_farmaco1.getText().toString().trim() ));

		p.setFarmaco_oppiaceo(new FarmacoDos( spinner_farmaco2.getSelectedItem().toString(), editText_dos_farmaco2.getText().toString().trim() ));

		p.setRescue(new Rescue( spinner_rescue.getSelectedItem().toString(), spinner_posologia_rescue.getSelectedItem().toString() ));

		p.setElastomero(new Elastomero(spinner_volume.getSelectedItem().toString(), spinner_velocita.getSelectedItem().toString() ));
		p.setIntegra_paracetamolo(checkbox_paracetamolo.isChecked());

		p.setGastro(new Gastroprotezione( spinner_gastro.getSelectedItem().toString(), editText_dos_gastro.getText().toString() ));
		p.setPonv(new Ponv( spinner_ponv.getSelectedItem().toString(), spinner_pos_ponv.getSelectedItem().toString() ,editText_dos_ponv.getText().toString() ));
		return p;
	}

	@Override
	public boolean savePazienteProtocollo(Paziente paziente, AbstractProtocollo prot) {

		return datasource.createPazienteAndProtocollo(paziente, prot);
	}

	@Override
	public void onResume() {
		datasource.open();
		super.onResume();
	}

	@Override
	public void onPause() {
		datasource.close();
		super.onPause();
	}

	private class ElastomeroListener implements AdapterView.OnItemSelectedListener
	{
		public void onItemSelected(AdapterView<?> parent, View v, int position, long id) {

			int volume = Integer.parseInt( spinner_volume.getSelectedItem().toString());
			int velocita = Integer.parseInt( spinner_velocita.getSelectedItem().toString());
			float time = (float) volume / (float) velocita;
			int hours = (int) time;
			int minutes = (int) (60 * (time - hours));
			Calendar data = Calendar.getInstance();
			data.add(Calendar.HOUR_OF_DAY, hours);
			data.add(Calendar.MINUTE, minutes);
			SimpleDateFormat format = new SimpleDateFormat("HH:mm 'del' dd-MM-yyyy", Locale.getDefault());
			textView_stima.setText( format.format(data.getTime()));
		}
		public void onNothingSelected(AdapterView<?> arg0) {
			// TODO Auto-generated method stub

		}
	}
}


