/*
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package prova.med.wifidirect;

import android.app.Fragment;
import android.app.ProgressDialog;
import android.content.Context;
import android.net.wifi.WpsInfo;
import android.net.wifi.p2p.WifiP2pConfig;
import android.net.wifi.p2p.WifiP2pDevice;
import android.net.wifi.p2p.WifiP2pInfo;
import android.net.wifi.p2p.WifiP2pManager.ConnectionInfoListener;
import android.os.AsyncTask;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;
import prova.med.obj.AbstractProtocollo;
import prova.med.obj.Rilevazione;
import prova.med.Ilisterners.DeviceActionListener;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.net.InetSocketAddress;
import java.net.ServerSocket;
import java.net.Socket;
import java.util.ArrayList;
import java.util.HashMap;

import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonParser;

import prova.med.activities.WiFiDirectActivity;
import prova.med.boris.R;
import prova.med.db.SyncDBAdapter;
import prova.med.db.SyncDBAdapterClient;
import prova.med.db.SyncDBAdapterServer;

/**
 * Fragment che si occupa della connessione e del trasferimento dati
 */
public class DeviceActionFragment extends Fragment implements ConnectionInfoListener {

	private View mContentView = null;
	private WifiP2pDevice device;
	private WifiP2pInfo info;
	ProgressDialog progressDialog = null;

	@Override
	public void onActivityCreated(Bundle savedInstanceState) {
		super.onActivityCreated(savedInstanceState);
	}

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {

		mContentView = inflater.inflate(R.layout.device_action, null);
		mContentView.findViewById(R.id.btn_connect).setOnClickListener(new View.OnClickListener() {

			@Override
			public void onClick(View v) {
				WifiP2pConfig config = new WifiP2pConfig();
				config.deviceAddress = device.deviceAddress;
				config.wps.setup = WpsInfo.PBC;
				if (progressDialog != null && progressDialog.isShowing()) {
					progressDialog.dismiss();
				}
				progressDialog = ProgressDialog.show(getActivity(), "Premi indietro per annullare",
						"Connessione a :" + device.deviceAddress, true, true );
				((DeviceActionListener) getActivity()).connect(config);

			}
		});

		mContentView.findViewById(R.id.btn_disconnect).setOnClickListener(
				new View.OnClickListener() {

					@Override
					public void onClick(View v) {
						((DeviceActionListener) getActivity()).disconnect();
					}
				});

		mContentView.findViewById(R.id.btn_start_client).setOnClickListener(
				new View.OnClickListener() {

					@Override
					public void onClick(View v) {


						TextView statusText = (TextView) mContentView.findViewById(R.id.status_text);
						Button button = (Button)mContentView.findViewById(R.id.btn_start_client);
						new ClientAsyncTask(getActivity(), statusText, button).execute(new String[]{info.groupOwnerAddress.getHostAddress(), "8988"});

					}
				});

		return mContentView;
	}


	@Override
	public void onConnectionInfoAvailable(final WifiP2pInfo info) {
		if (progressDialog != null && progressDialog.isShowing()) {
			progressDialog.dismiss();
		}
		this.info = info;
		this.getView().setVisibility(View.VISIBLE);

		//il groupOwner crea la sua server socket
		if (info.groupFormed && info.isGroupOwner) {
			new ServerAsyncTask(getActivity(), mContentView.findViewById(R.id.status_text)).execute();
		} else if (info.groupFormed) {

			//L'altro device fa da client, manda i propri dati da processare
			mContentView.findViewById(R.id.btn_start_client).setVisibility(View.VISIBLE);
			((TextView) mContentView.findViewById(R.id.status_text)).setText("Click su Invio per trasmettere i dati e ricevere quelli aggiornati");
		}

		// nascondiamo tasto di connessione
		mContentView.findViewById(R.id.btn_connect).setVisibility(View.GONE);
	}

	/**
	 * Mostra bottoni
	 * 
	 * @param device the device to be displayed
	 */
	public void showActions(WifiP2pDevice device) {
		this.device = device;
		this.getView().setVisibility(View.VISIBLE);

	}
	/**
	 * Pulisce e resetta la vista dopo la disconessione.
	 */
	public void resetViews() {
		mContentView.findViewById(R.id.btn_connect).setVisibility(View.VISIBLE);
		TextView view = (TextView) mContentView.findViewById(R.id.status_text);
		view.setText(R.string.empty);
		mContentView.findViewById(R.id.btn_start_client).setVisibility(View.GONE);
		this.getView().setVisibility(View.GONE);
	}

	/**
	 * AsyncTask Server
	 */
	public static class ServerAsyncTask extends AsyncTask<Void, Void, String> {

		private Context context;
		private TextView statusText;

		/**
		 * @param context
		 * @param statusText
		 */
		public ServerAsyncTask(Context context, View statusText) {
			this.context = context;
			this.statusText = (TextView) statusText;
		}

		@Override
		protected void onPreExecute() {
			statusText.setText("In attesa di trasferimenti...");
		}

		@Override
		protected String doInBackground(Void... params) {
			try {
				ServerSocket serverSocket = new ServerSocket(8988);
				Log.d(WiFiDirectActivity.TAG, "Server: Socket opened");
				Socket socket = serverSocket.accept();
				Log.d(WiFiDirectActivity.TAG, "Server: connection done");
				ObjectInputStream in = new ObjectInputStream(socket.getInputStream());
				ObjectOutputStream out = new ObjectOutputStream(socket.getOutputStream());

				JsonArray pazienti_received = new JsonParser().parse((String)in.readObject() ).getAsJsonArray();
				HashMap<String, HashMap<String, AbstractProtocollo>> protocolli_received = (HashMap<String, HashMap<String, AbstractProtocollo>>) in.readObject();
				HashMap<String, ArrayList<Rilevazione>> rilevazioni_received = (HashMap<String, ArrayList<Rilevazione>>) in.readObject();
				ArrayList<String> cancellati_received = (ArrayList<String>) in.readObject();


				SyncDBAdapterServer datasource = new SyncDBAdapterServer(context);
				datasource.open();
				String result = datasource.syncDB(pazienti_received,protocolli_received, rilevazioni_received, cancellati_received);
				out.writeObject(result);

				if(result.equals(SyncDBAdapterServer.SUCCESS))
				{
					String towrite = new Gson().toJson(datasource.getPazientiDBTableAsJsonArray());
					out.writeObject(towrite);
					out.flush();
					out.writeObject(datasource.getProtocolliAsHashMap());
					out.flush();
					out.writeObject(datasource.getRilevazioniDBTableAsHashMap());
					out.flush();
					out.writeObject(datasource.getPazientiCancellatiAsArrayList());
				}
				in.close();
				out.close();

				datasource.close();


				socket.close();
				serverSocket.close();
				return result;
			} catch (IOException e) {
				Log.e(WiFiDirectActivity.TAG, e.getMessage());
				return e.toString();
			}
			catch (ClassCastException e) {
				Log.e(WiFiDirectActivity.TAG, e.getMessage());
				return e.toString();
			}
			catch (Exception e) {
				Log.e(WiFiDirectActivity.TAG, e.getMessage());
				return e.toString();
			}
		}

		/*
		 * (non-Javadoc)
		 * @see android.os.AsyncTask#onPostExecute(java.lang.Object)
		 */
		@Override
		protected void onPostExecute(String result) {
				statusText.setText(result);
		}
	}

	public static class ClientAsyncTask extends AsyncTask<String, Void, String> {

		private Context context;
		private TextView statusText;
		private Button button;

		/**
		 * @param context
		 * @param statusText
		 * @param button
		 */
		public ClientAsyncTask(Context context, TextView statusText, Button button) {
			this.context = context;
			this.statusText = statusText;
			this.button = button;
		}

		@Override
		protected void onPreExecute() {
			statusText.setText("Trasferimento dati... ");
		}

		@Override
		protected String doInBackground(String... params) {

			String host = params[0];
			Socket socket = new Socket();
			int port = Integer.parseInt(params[1]);
			int time_out = 10000;
			String result = "";
			
			try {
				Log.d(WiFiDirectActivity.TAG, "Opening client socket - ");
				socket.bind(null);
				socket.connect((new InetSocketAddress(host, port)), time_out);

				Log.d(WiFiDirectActivity.TAG, "Client socket - " + socket.isConnected());

				ObjectOutputStream out = new ObjectOutputStream(socket.getOutputStream());
				ObjectInputStream in = new ObjectInputStream(socket.getInputStream());

				SyncDBAdapterClient datasource = new SyncDBAdapterClient(context);
				datasource.open();

				//mando dati
				String towrite = new Gson().toJson(datasource.getPazientiDBTableAsJsonArray());
				out.writeObject(towrite);
				out.flush();
				out.writeObject(datasource.getProtocolliAsHashMap());
				out.flush();
				out.writeObject(datasource.getRilevazioniDBTableAsHashMap());
				out.flush();
				out.writeObject(datasource.getPazientiCancellatiAsArrayList());

				//ricevo db sincronizzato

				String result_from_other = (String)in.readObject();
				if(result_from_other.equals(SyncDBAdapter.SUCCESS))
				{
					JsonArray pazienti_received = new JsonParser().parse((String)in.readObject() ).getAsJsonArray();
					HashMap<String, HashMap<String, AbstractProtocollo>> protocolli_received = (HashMap<String, HashMap<String, AbstractProtocollo>>) in.readObject();
					HashMap<String, ArrayList<Rilevazione>> rilevazioni_received = (HashMap<String, ArrayList<Rilevazione>>) in.readObject();
					ArrayList<String> cancellati_received = (ArrayList<String>) in.readObject();

					//sovrascrivo dati
					result = datasource.writeSyncedDB(pazienti_received, protocolli_received, rilevazioni_received, cancellati_received);

				}
				datasource.close();
				out.close();
				in.close();

				Log.d(WiFiDirectActivity.TAG, "Client: Data written");

			} catch (IOException e) {
				Log.e(WiFiDirectActivity.TAG, e.getMessage());
				return e.toString();
			} catch (Exception e) {
				e.printStackTrace();
				return e.toString();
			} finally {
				if (socket != null) {
					if (socket.isConnected()) {
						try {
							socket.close();
						} catch (IOException e) {
							// Give up
							e.printStackTrace();
							return e.toString();
						}

					}
				}
			}

			return result;
		}

		@Override
		protected void onPostExecute(String result) {
			button.setVisibility(View.GONE);
			statusText.setText(result);
		}

	}

}
